@@ -1,8 +1,6 @@
-# coding: utf-8
-from __future__ import absolute_import
-from __future__ import unicode_literals
-
-from django.apps.config import AppConfig as AppConfigBase
+from django.apps.config import (
+    AppConfig as AppConfigBase,
+)
 
 
 class AppConfig(AppConfigBase):
