@@ -1,8 +1,6 @@
-# coding: utf-8
-from __future__ import absolute_import
-
-from celery.result import states
-import six
+from celery.result import (
+    states,
+)
 
 
 STATUS_PENDING = 1
@@ -30,20 +28,20 @@ TASK_STATES = {
 }
 
 # состояния задач celery по статусам
-TASK_STATUSES = dict((v, k) for k, v in six.iteritems(TASK_STATES))
+TASK_STATUSES = dict((v, k) for k, v in TASK_STATES.items())
 
 
 # отображение статусов
 STATUS_CHOICES = (
-    (STATUS_PENDING, u'Неизвестно'),
-    (STATUS_RECEIVED, u'В очереди'),
-    (STATUS_STARTED, u'Выполняется'),
-    (STATUS_SUCCESS, u'Успешно выполнена'),
-    (STATUS_REVOKED, u'Остановлена'),
-    (STATUS_FAILURE, u'Ошибка'),
-    (STATUS_RETRY, u'Перезапуск'),
-    (STATUS_IGNORED, u'Игнорирована'),
-    (STATUS_REJECTED, u'Отменена'),
+    (STATUS_PENDING, 'Неизвестно'),
+    (STATUS_RECEIVED, 'В очереди'),
+    (STATUS_STARTED, 'Выполняется'),
+    (STATUS_SUCCESS, 'Успешно выполнена'),
+    (STATUS_REVOKED, 'Остановлена'),
+    (STATUS_FAILURE, 'Ошибка'),
+    (STATUS_RETRY, 'Перезапуск'),
+    (STATUS_IGNORED, 'Игнорирована'),
+    (STATUS_REJECTED, 'Отменена'),
 )
 
 
