@@ -1,6 +1,3 @@
-# coding: utf-8
-from __future__ import absolute_import
-
 import os
 
 
@@ -24,8 +21,11 @@ EXCLUDED_TABLES = (
 )
 
 # Папка с sql файлами
-SQL_FILES_DIR = os.path.abspath(os.path.join(
-    os.path.dirname(__file__), 'sql',
-))
+SQL_FILES_DIR = os.path.abspath(
+    os.path.join(
+        os.path.dirname(__file__),
+        'sql',
+    )
+)
 
-INSTALL_AUDIT_LOG_SQL_FILE_NAME = 'install_audit_log.sql'
\ No newline at end of file
+INSTALL_AUDIT_LOG_SQL_FILE_NAME = 'install_audit_log.sql'
