@@ -1,12 +1,9 @@
-# coding: utf-8
-from __future__ import absolute_import
-from __future__ import unicode_literals
-
-from django.db import migrations
+from django.db import (
+    migrations,
+)
 
 
 class Migration(migrations.Migration):
-
     dependencies = [
         ('audit_log', '0002_install_audit_log'),
     ]
@@ -14,8 +11,7 @@ class Migration(migrations.Migration):
     operations = [
         migrations.CreateModel(
             name='LogProxy',
-            fields=[
-            ],
+            fields=[],
             options={
                 'proxy': True,
             },
