@@ -1,7 +1,6 @@
-# coding: utf-8
-from __future__ import absolute_import
-
-from educommon.django.db.routers import ServiceDbRouterBase
+from educommon.django.db.routers import (
+    ServiceDbRouterBase,
+)
 
 
 class AuditLogRouter(ServiceDbRouterBase):
