@@ -1,71 +1,116 @@
-# coding: utf-8
-u"""Паки и экшены для окна реестра "Роли"."""
-from __future__ import absolute_import
+"""Паки и экшены для окна реестра "Роли"."""
 
-from collections import defaultdict
-from functools import reduce
-from itertools import chain
-from operator import or_
 import json
+from collections import (
+    defaultdict,
+)
+from functools import (
+    reduce,
+)
+from itertools import (
+    chain,
+)
+from operator import (
+    or_,
+)
 
-from django.contrib.contenttypes.models import ContentType
-from django.db.models import Case
-from django.db.models import F
-from django.db.models import Q
-from django.db.models import Value
-from django.db.models import When
-from django.db.models.fields import CharField
-from django.db.models.functions import Concat
-from django.utils.functional import cached_property
-from m3.actions import ApplicationLogicException
-from m3.actions import PreJsonResult
-from m3.actions.results import OperationResult
-from m3_django_compat import atomic
-from m3_django_compat import get_request_params
-from objectpack.actions import BaseAction
-from objectpack.actions import BasePack
-from objectpack.actions import ObjectPack
-from objectpack.actions import ObjectRowsAction
-from objectpack.actions import ObjectSelectWindowAction
-from objectpack.exceptions import ValidationError
-from objectpack.models import VirtualModel
-from objectpack.tools import extract_int_list
-from objectpack.tree_object_pack.actions import TreeObjectPack
-import six
+from django.contrib.contenttypes.models import (
+    ContentType,
+)
+from django.db.models import (
+    Case,
+    F,
+    Q,
+    Value,
+    When,
+)
+from django.db.models.fields import (
+    CharField,
+)
+from django.db.models.functions import (
+    Concat,
+)
+from django.utils.functional import (
+    cached_property,
+)
+from m3.actions import (
+    ApplicationLogicException,
+    PreJsonResult,
+)
+from m3.actions.results import (
+    OperationResult,
+)
+from m3_django_compat import (
+    atomic,
+    get_request_params,
+)
 
-from educommon.auth.rbac.config import rbac_config
-from educommon.auth.rbac.utils import get_permission_full_title
-from educommon.m3 import convert_validation_error_to
-from educommon.m3 import get_id_value
-from educommon.m3 import get_pack
-from educommon.m3 import get_pack_id
+from objectpack.actions import (
+    BaseAction,
+    BasePack,
+    ObjectPack,
+    ObjectRowsAction,
+    ObjectSelectWindowAction,
+)
+from objectpack.exceptions import (
+    ValidationError,
+)
+from objectpack.models import (
+    VirtualModel,
+)
+from objectpack.tools import (
+    extract_int_list,
+)
+from objectpack.tree_object_pack.actions import (
+    TreeObjectPack,
+)
 
-from . import ui
-from .constants import PERM_SOURCE__DEPENDENCIES
-from .constants import PERM_SOURCE__NESTED_ROLE
-from .constants import PERM_SOURCE__ROLE
-from .manager import rbac
-from .models import Permission
-from .models import Role
-from .models import RoleParent
-from .models import RolePermission
-from .models import RoleUserType
-from .models import UserRole
-from .permissions import PERM_GROUP__ROLE
+from educommon.auth.rbac import (
+    ui,
+)
+from educommon.auth.rbac.config import (
+    rbac_config,
+)
+from educommon.auth.rbac.constants import (
+    PERM_SOURCE__DEPENDENCIES,
+    PERM_SOURCE__NESTED_ROLE,
+    PERM_SOURCE__ROLE,
+)
+from educommon.auth.rbac.manager import (
+    rbac,
+)
+from educommon.auth.rbac.models import (
+    Permission,
+    Role,
+    RoleParent,
+    RolePermission,
+    RoleUserType,
+    UserRole,
+)
+from educommon.auth.rbac.permissions import (
+    PERM_GROUP__ROLE,
+)
+from educommon.auth.rbac.utils import (
+    get_permission_full_title,
+)
+from educommon.m3 import (
+    convert_validation_error_to,
+    get_id_value,
+    get_pack,
+    get_pack_id,
+)
 
 
 def _get_role(role_id):
+    """Возвращает объект роли по ID или выбрасывает исключение."""
     try:
         return Role.objects.get(pk=role_id)
     except Role.DoesNotExist:
-        raise ApplicationLogicException(
-            u'Роль ID:{} не существует'.format(role_id)
-        )
+        raise ApplicationLogicException('Роль ID:{} не существует'.format(role_id))
 
 
 class RolesTreeRowsAction(ObjectRowsAction):
-
-    u"""Экшн, отдающий данные иерархии ролей.
+    """Экшн, отдающий данные иерархии ролей.
 
     Т.к. одна и та же роль может быть включена в несколько ролей, то она также
     может отображаться вложенной в несколько ролей.
@@ -73,7 +118,7 @@ class RolesTreeRowsAction(ObjectRowsAction):
 
     @cached_property
     def _parent_ids(self):
-        u"""Id ролей, содержащих в себе другие роли.
+        """Id ролей, содержащих в себе другие роли.
 
         :rtype: set
         """
@@ -82,7 +127,7 @@ class RolesTreeRowsAction(ObjectRowsAction):
         return set(result)
 
     def is_leaf(self, role):
-        u"""Возвращает True, если данная роль не включает другие роли.
+        """Возвращает True, если данная роль не включает другие роли.
 
         :param role: Роль.
         :type role: Role
@@ -97,15 +142,16 @@ class RolesTreeRowsAction(ObjectRowsAction):
         return result
 
     def prepare_object(self, obj):
-        u"""Сохранение данных роли в словарь перед сериализацией в JSON."""
-        data = super(RolesTreeRowsAction, self).prepare_object(obj)
+        """Сохранение данных роли в словарь перед сериализацией в JSON."""
+        data = super().prepare_object(obj)
 
         data['leaf'] = self.is_leaf(obj)
 
         return data
 
     def run(self, *args, **kwargs):
-        result = super(RolesTreeRowsAction, self).run(*args, **kwargs)
+        """Тело Action, вызывается при обработке запроса к серверу."""
+        result = super().run(*args, **kwargs)
 
         data = result.data.get('rows', [])
 
@@ -113,14 +159,18 @@ class RolesTreeRowsAction(ObjectRowsAction):
 
 
 class AddRoleToRoleWindowAction(ObjectSelectWindowAction):
-
-    u"""Отображение окна добавления одной роли в другую."""
+    """Отображение окна добавления одной роли в другую."""
 
     def create_window(self):
+        """Метод инстанцирует окно."""
         self.win = ui.RoleSelectWindow()
 
     def set_window_params(self):
-        super(AddRoleToRoleWindowAction, self).set_window_params()
+        """Метод заполняет словарь self.win_params, который будет передан в окно.
+
+        Этот словарь выступает как шина передачи данных от Actions/Packs к окну.
+        """
+        super().set_window_params()
 
         self.win_params['pack'] = self.parent
 
@@ -130,11 +180,11 @@ class AddRoleToRoleWindowAction(ObjectSelectWindowAction):
 
 
 class AddRoleToRoleAction(BaseAction):
-
-    u"""Добавление одной роли к другой."""
+    """Добавление одной роли к другой."""
 
     @convert_validation_error_to(ApplicationLogicException)
     def run(self, request, context):
+        """Тело Action, вызывается при обработке запроса к серверу."""
         role_parent = RoleParent(
             role=_get_role(getattr(context, self.parent.id_param_name)),
             parent=_get_role(context.parent_id),
@@ -146,19 +196,16 @@ class AddRoleToRoleAction(BaseAction):
 
 
 class DeleteRoleFromRoleAction(BaseAction):
-
-    u"""Удаление одной роли из другой."""
+    """Удаление одной роли из другой."""
 
     def run(self, request, context):
+        """Тело Action, вызывается при обработке запроса к серверу."""
         try:
             role_parent = RoleParent.objects.get(
-                role=_get_role(getattr(context, self.parent.id_param_name)),
-                parent_id=context.parent_id
+                role=_get_role(getattr(context, self.parent.id_param_name)), parent_id=context.parent_id
             )
         except RoleParent.DoesNotExist:
-            raise ApplicationLogicException(
-                u'Выбранная роль должна являться вложенной ролью.'
-            )
+            raise ApplicationLogicException('Выбранная роль должна являться вложенной ролью.')
 
         role_parent.delete()
 
@@ -166,16 +213,15 @@ class DeleteRoleFromRoleAction(BaseAction):
 
 
 class Pack(TreeObjectPack):
-
-    u"""Пак окна реестра "Роли"."""
+    """Пак окна реестра "Роли"."""
 
     model = Role
-    title = u'Роли'
+    title = 'Роли'
 
     columns = [
         dict(
             data_index='name',
-            header=u'Название',
+            header='Название',
             searchable=True,
         ),
     ]
@@ -187,7 +233,7 @@ class Pack(TreeObjectPack):
     column_name_on_select = 'name'
 
     def __init__(self):
-        super(Pack, self).__init__()
+        super().__init__()
 
         self.replace_action('rows_action', RolesTreeRowsAction())
 
@@ -195,45 +241,50 @@ class Pack(TreeObjectPack):
         self.add_role_to_role_action = AddRoleToRoleAction()
         self.delete_role_from_role_action = DeleteRoleFromRoleAction()
 
-        self.actions.extend((
-            self.add_role_to_role_window_action,
-            self.add_role_to_role_action,
-            self.delete_role_from_role_action,
-        ))
+        self.actions.extend(
+            (
+                self.add_role_to_role_window_action,
+                self.add_role_to_role_action,
+                self.delete_role_from_role_action,
+            )
+        )
         # ---------------------------------------------------------------------
         # Настройка разрешений для экшенов пака.
         self.need_check_permission = True
         self.perm_code = PERM_GROUP__ROLE
 
-        for action in (self.autocomplete_action,
-                       self.list_window_action,
-                       self.multi_select_window_action,
-                       self.rows_action,
-                       self.select_window_action,
-                       self.edit_window_action):
+        for action in (
+            self.autocomplete_action,
+            self.list_window_action,
+            self.multi_select_window_action,
+            self.rows_action,
+            self.select_window_action,
+            self.edit_window_action,
+        ):
             action.perm_code = 'view'
 
-        for action in (self.new_window_action,
-                       self.save_action,
-                       self.delete_action,
-                       self.add_role_to_role_window_action,
-                       self.add_role_to_role_action,
-                       self.delete_role_from_role_action):
+        for action in (
+            self.new_window_action,
+            self.save_action,
+            self.delete_action,
+            self.add_role_to_role_window_action,
+            self.add_role_to_role_action,
+            self.delete_role_from_role_action,
+        ):
             action.perm_code = 'edit'
         # ---------------------------------------------------------------------
 
     def extend_menu(self, menu):
-        u"""Размещает в меню Пуск ссылку Администрирование --> Роли."""
+        """Размещает в меню Пуск ссылку Администрирование --> Роли."""
         return menu.administry(
             menu.Item(self.title, self.list_window_action),
         )
 
     def declare_context(self, action):
-        result = super(Pack, self).declare_context(action)
+        """Декларирует контекст для экшна."""
+        result = super().declare_context(action)
 
-        if action in (self.rows_action,
-                      self.add_role_to_role_window_action,
-                      self.add_role_to_role_action):
+        if action in (self.rows_action, self.add_role_to_role_window_action, self.add_role_to_role_action):
             result[self.id_param_name] = dict(type='int')
 
         if action is self.rows_action:
@@ -245,8 +296,8 @@ class Pack(TreeObjectPack):
 
         if action is self.save_action:
             result.update(
-                name=dict(type='unicode'),
-                description=dict(type='unicode', default=u''),
+                name=dict(type='str'),
+                description=dict(type='str', default=''),
                 permissions=dict(type='int_list', default=[]),
                 user_type_ids=dict(type='json_or_none', default=None),
             )
@@ -256,27 +307,22 @@ class Pack(TreeObjectPack):
         return result
 
     def get_rows_query(self, request, context):
+        """Возвращает выборку из БД для получения списка данных."""
         request_params = get_request_params(request)
         if request_params.get('filter'):
-            return super(Pack, self).get_rows_query(request, context)
+            return super().get_rows_query(request, context)
 
         current_role_id = getattr(context, self.id_param_name)
 
         if request_params.get('filter', False):
-            result = super(Pack, self).get_rows_query(
-                request, context
-            )
+            result = super().get_rows_query(request, context)
         elif current_role_id < 0:
             # Вывод корневых ролей
-            result = self.model.objects.exclude(
-                pk__in=RoleParent.objects.values('role').distinct()
-            )
+            result = self.model.objects.exclude(pk__in=RoleParent.objects.values('role').distinct())
         else:
             # Вывод ролей, вложенных в указанную роль
             result = self.model.objects.filter(
-                pk__in=RoleParent.objects.filter(
-                    parent=current_role_id
-                ).values('role').distinct()
+                pk__in=RoleParent.objects.filter(parent=current_role_id).values('role').distinct()
             )
 
         if context.select_mode and context.role_id is not None:
@@ -287,20 +333,15 @@ class Pack(TreeObjectPack):
             try:
                 role = Role.objects.get(pk=context.role_id)
             except Role.DoesNotExist:
-                raise ApplicationLogicException(
-                    u'Роль ID:{} не найдена'.format(context.role_id)
-                )
+                raise ApplicationLogicException('Роль ID:{} не найдена'.format(context.role_id))
 
-            result = result.exclude(
-                pk__in=set([role.id]) | set(r.id for r in role.subroles)
-            )
+            result = result.exclude(pk__in=set([role.id]) | set(r.id for r in role.subroles))
 
         return result
 
     def get_list_window_params(self, params, request, context):
-        params = super(Pack, self).get_list_window_params(
-            params, request, context
-        )
+        """Возвращает словарь параметров, которые будут переданы окну списка."""
+        params = super().get_list_window_params(params, request, context)
 
         if not params['is_select_mode']:
             params['width'] = 700
@@ -311,9 +352,8 @@ class Pack(TreeObjectPack):
         return params
 
     def get_edit_window_params(self, params, request, context):
-        params = super(Pack, self).get_edit_window_params(
-            params, request, context
-        )
+        """Возвращает словарь параметров, которые будут переданы окну редактирования."""
+        params = super().get_edit_window_params(params, request, context)
 
         params['roles_pack'] = self
         params['partitions_pack'] = get_pack(PartitionsPack)
@@ -327,31 +367,23 @@ class Pack(TreeObjectPack):
             params['show_user_types'] = True
             params['user_types'] = tuple(
                 (u_type.id, u_type.name)
-                for u_type in six.itervalues(
-                    ContentType.objects.get_for_models(
-                        *rbac_config.user_types
-                    )
-                )
+                for u_type in (ContentType.objects.get_for_models(*rbac_config.user_types).values())
             )
             if not params['create_new']:
-                params['user_type_ids'] = tuple(
-                    params['object'].user_types.values_list('pk', flat=True)
-                )
+                params['user_type_ids'] = tuple(params['object'].user_types.values_list('pk', flat=True))
 
         if not params['create_new']:
-            params['permission_ids'] = list(
-                params['object'].permissions.values_list('pk', flat=True)
-            )
+            params['permission_ids'] = list(params['object'].permissions.values_list('pk', flat=True))
 
         params['can_edit'] = rbac.has_access(self.save_action, request)
         if not params['can_edit']:
-            params['title'] = self.format_window_title(u'Просмотр')
+            params['title'] = self.format_window_title('Просмотр')
 
         return params
 
     @staticmethod
     def _bind_user_types_to_role(role, types):
-        u"""Привязывает типы пользователей к роли.
+        """Привязывает типы пользователей к роли.
 
         При необходимости удаления типов пользователей, происходит
         проверка на наличие уже существующих пользователей с
@@ -372,33 +404,25 @@ class Pack(TreeObjectPack):
         )
         # Проверка, есть ли пользователи с удаляемыми типами
         if types_to_delete and user_roles_to_delete.exists():
-            related_content_types = ContentType.objects.filter(
-                pk__in=types_to_delete
-            )
+            related_content_types = ContentType.objects.filter(pk__in=types_to_delete)
             raise ApplicationLogicException(
-                u'Невозможно отменить назначение роли для пользователей '
-                u'типа {}, т.к. данная роль уже назначена {} '
-                u'пользователей.'.format(
-                    u', '.join(
-                        u'"{}"'.format(ct.name) for ct in related_content_types
-                    ),
-                    u'этому типу'
-                    if len(types_to_delete) == 1 else u'этим типам',
+                'Невозможно отменить назначение роли для пользователей '
+                'типа {}, т.к. данная роль уже назначена {} '
+                'пользователей.'.format(
+                    ', '.join('"{}"'.format(ct.name) for ct in related_content_types),
+                    'этому типу' if len(types_to_delete) == 1 else 'этим типам',
                 )
             )
         # Удаление лишних типов пользователей
-        RoleUserType.objects.filter(
-            role=role, user_type__in=types_to_delete
-        ).delete()
+        RoleUserType.objects.filter(role=role, user_type__in=types_to_delete).delete()
         # Добавление новых типов пользователей
         for user_type_id in new_user_types - old_user_types:
-            RoleUserType.objects.create(
-                role=role, user_type_id=user_type_id
-            )
+            RoleUserType.objects.create(role=role, user_type_id=user_type_id)
 
     @convert_validation_error_to(ValidationError)
     @atomic
     def save_row(self, obj, create_new, request, context):
+        """Сохраняет объект."""
         # При отключении флага удаляются все связи с типами пользователей
         if not (create_new or obj.can_be_assigned):
             RoleUserType.objects.filter(role=obj).delete()
@@ -413,9 +437,7 @@ class Pack(TreeObjectPack):
             try:
                 parent = Role.objects.get(pk=context.parent_id)
             except Role.DoesNotExist:
-                raise ApplicationLogicException(
-                    u'Роль ID:{} не существует.'.format(context.parent_id)
-                )
+                raise ApplicationLogicException('Роль ID:{} не существует.'.format(context.parent_id))
 
             RoleParent.objects.create(role=obj, parent=parent)
         else:
@@ -431,15 +453,11 @@ class Pack(TreeObjectPack):
 
             # Добавление новых прав в роль
             for permission_id in new_permissions - old_permissions:
-                RolePermission.objects.get_or_create(
-                    role=obj, permission_id=permission_id
-                )
+                RolePermission.objects.get_or_create(role=obj, permission_id=permission_id)
 
 
-@six.python_2_unicode_compatible
 class Partition(VirtualModel):
-
-    u"""Виртуальная модель "Раздел системы".
+    """Виртуальная модель "Раздел системы".
 
     Используется в связи с тем, что сведения о разделах не сохраняются в БД.
     """
@@ -449,6 +467,12 @@ class Partition(VirtualModel):
 
     @classmethod
     def _get_ids(cls):
+        """Метод получения ID и названий разделов системы.
+
+        Метод возвращает iterable, или callable, возвращаюший iterable,
+        для каждого элемента которого (iterable) будет инстанцирован объект класса
+        (каждый эл-т итератора передаётся в конструктор).
+        """
         if not hasattr(cls, 'data'):
             cls.data = []
             for i, title in enumerate(sorted(rbac.partitions)):
@@ -461,22 +485,21 @@ class Partition(VirtualModel):
 
 
 class PartitionsPack(ObjectPack):
-
-    u"""Пак для грида "Разделы системы" окна редактирования роли."""
+    """Пак для грида "Разделы системы" окна редактирования роли."""
 
     model = Partition
 
     columns = [
         dict(
             data_index='__str__',
-            header=u'Модуль',
+            header='Модуль',
         ),
     ]
 
     allow_paging = False
 
     def __init__(self):
-        super(PartitionsPack, self).__init__()
+        super().__init__()
         # ---------------------------------------------------------------------
 
         self.need_check_permission = True
@@ -488,15 +511,14 @@ class PartitionsPack(ObjectPack):
 
 
 class PermissionsPack(ObjectPack):
-
-    u"""Пак для грида "Права доступа" окна редактирования роли."""
+    """Пак для грида "Права доступа" окна редактирования роли."""
 
     model = Permission
 
     columns = (
         dict(
             data_index='title_with_group',
-            header=u'Разрешение',
+            header='Разрешение',
             column_renderer='columnRenderer',
             width=4,
         ),
@@ -506,7 +528,7 @@ class PermissionsPack(ObjectPack):
         ),
         dict(
             data_index='dependencies',
-            header=u'Включает разрешения',
+            header='Включает разрешения',
             width=5,
         ),
     )
@@ -515,18 +537,17 @@ class PermissionsPack(ObjectPack):
     allow_paging = False
 
     def __init__(self):
-        super(PermissionsPack, self).__init__()
-        # ---------------------------------------------------------------------
+        super().__init__()
 
         self.need_check_permission = True
         self.perm_code = PERM_GROUP__ROLE
 
         for action in self.actions:
             action.perm_code = 'view'
-        # ---------------------------------------------------------------------
 
     def declare_context(self, action):
-        result = super(PermissionsPack, self).declare_context(action)
+        """Декларирует контекст для экшна"""
+        result = super().declare_context(action)
 
         if action is self.rows_action:
             result['partition_id'] = dict(type='int')
@@ -534,84 +555,88 @@ class PermissionsPack(ObjectPack):
         return result
 
     def prepare_row(self, obj, request, context):
-        result = super(PermissionsPack, self).prepare_row(
-            obj, request, context
-        )
+        """Установка дополнительных атрибутов объекта."""
+        result = super().prepare_row(obj, request, context)
 
-        permission_names = (
-            rbac.get_dependent_permissions(obj.name) - rbac.hidden_permissions
+        permission_names = rbac.get_dependent_permissions(obj.name) - rbac.hidden_permissions
+        result.dependencies = json.dumps(
+            sorted(get_permission_full_title(dependency) for dependency in permission_names)
         )
-        result.dependencies = json.dumps(sorted(
-            get_permission_full_title(dependency)
-            for dependency in permission_names
-        ))
 
         return result
 
     def get_rows_query(self, request, context):
+        """Возвращает выборку из БД для получения списка данных."""
         # Определение название раздела по его id.
         try:
-            partition = PartitionsPack.model.objects.get(
-                id=context.partition_id
-            ).title
+            partition = PartitionsPack.model.objects.get(id=context.partition_id).title
         except PartitionsPack.model.DoesNotExists:
-            raise ApplicationLogicException(
-                u'Раздел {} не существует'.format(context.partition_id)
-            )
+            raise ApplicationLogicException('Раздел {} не существует'.format(context.partition_id))
 
-        query = super(PermissionsPack, self).get_rows_query(
-            request, context
-        ).filter(
-            # Условия для выборки разрешений только из раздела partition.
-            reduce(or_, (
-                Q(name__startswith=code + '/')
-                for code in rbac.partitions[partition]
-            )),
-            hidden=False,
-        ).annotate(title_with_group=Case(
-            # Добавление названия группы к названию разрешения.
-            output_field=CharField(),
-            *(
-                When(
-                    name__startswith=group + '/',
-                    then=Concat(
-                        Value(title + u' - ' if title else u''),
-                        F('title'),
-                    )
-                )
-                for group, title in six.iteritems(rbac.groups)
+        query = (
+            super()
+            .get_rows_query(request, context)
+            .filter(
+                # Условия для выборки разрешений только из раздела partition.
+                reduce(or_, (Q(name__startswith=code + '/') for code in rbac.partitions[partition])),
+                hidden=False,
             )
-        ))
+            .annotate(
+                title_with_group=Case(
+                    # Добавление названия группы к названию разрешения.
+                    output_field=CharField(),
+                    *(
+                        When(
+                            name__startswith=group + '/',
+                            then=Concat(
+                                Value(title + ' - ' if title else ''),
+                                F('title'),
+                            ),
+                        )
+                        for group, title in rbac.groups.items()
+                    ),
+                )
+            )
+        )
 
         return query
+
+
 # -----------------------------------------------------------------------------
 
+
 def _get_group_name(perm_name):
     """Возвращает имя группы разрешения."""
     return perm_name.split('/')[0]
 
+
 def _get_group_title(perm_name):
-    u"""Возвращает название группы разрешений."""
+    """Возвращает название группы разрешений."""
     group_name = _get_group_name(perm_name)
     group_title = rbac.groups[group_name]
+
     return group_title
 
 
 def _get_partition_title(perm_name):
+    """Возвращает название раздела, к которому относится разрешение."""
     group_name = perm_name.split('/')[0]
 
-    for title, names in six.iteritems(rbac.partitions):
+    for title, names in rbac.partitions.items():
         if group_name in names:
             return title
 
-    return u''
+    return ''
 
 
 class ResultPermissionsAction(BaseAction):
-
-    u"""Возвращает данные для грида "Итоговые разрешения"."""
+    """Возвращает данные для грида "Итоговые разрешения"."""
 
     def _get_nested_roles(self, role_id):
+        """Возвращает все вложенные роли для заданной роли.
+
+        Строит рекурсивное множество дочерних ролей, включая вложенные на любой глубине.
+        """
         role_children = defaultdict(set)
         query = RoleParent.objects.values_list('parent', 'role')
 
@@ -631,10 +656,9 @@ class ResultPermissionsAction(BaseAction):
         return get_nested_roles(role_id)
 
     def _get_nested_roles_permissions(self, role_id):
+        """Возвращает разрешения, назначенные вложенным ролям заданной роли."""
         query = Permission.objects.filter(
-            pk__in=RolePermission.objects.filter(
-                role_id__in=self._get_nested_roles(role_id)
-            ).values('permission'),
+            pk__in=RolePermission.objects.filter(role_id__in=self._get_nested_roles(role_id)).values('permission'),
             hidden=False,
         ).values_list('name', 'title', 'description')
 
@@ -649,17 +673,19 @@ class ResultPermissionsAction(BaseAction):
             )
 
     def _get_dependent_permissions(self, permission_ids):
+        """Возвращает разрешения, от которых зависят указанные разрешения.
+
+        Исключает скрытые разрешения и формирует структуру для отображения
+        в интерфейсе.
+        """
         permissions_by_id = {
             pk: (name, title, description)
             for pk, name, title, description in Permission.objects.filter(
                 hidden=False,
-            ).values_list(
-                'pk', 'name', 'title', 'description'
-            )
+            ).values_list('pk', 'name', 'title', 'description')
         }
         permissions_by_name = {
-            name: (pk, title, description)
-            for pk, (name, title, description) in six.iteritems(permissions_by_id)
+            name: (pk, title, description) for pk, (name, title, description) in permissions_by_id.items()
         }
 
         for perm_id in permission_ids:
@@ -683,6 +709,7 @@ class ResultPermissionsAction(BaseAction):
                 )
 
     def _get_role_permissions(self, permission_ids):
+        """Возвращает основные разрешения, явно назначенные роли."""
         query = Permission.objects.filter(
             pk__in=permission_ids,
             hidden=False,
@@ -700,6 +727,15 @@ class ResultPermissionsAction(BaseAction):
                 )
 
     def run(self, request, context):
+        """Обрабатывает запрос на получение итоговых разрешений роли.
+
+        Комбинирует разрешения:
+        - явно назначенные роли;
+        - зависимые разрешения;
+        - разрешения вложенных ролей.
+
+        Возвращает данные, сгруппированные по разделам и группам.
+        """
         perm_names = set()
 
         data = defaultdict(lambda: defaultdict(list))
@@ -715,28 +751,27 @@ class ResultPermissionsAction(BaseAction):
                 partition_title = perm_data['partition']
                 group_title = perm_data['group']
 
-                data[partition_title][group_title].append(dict(
-                    title=perm_data['title'],
-                    description=perm_data['description'],
-                    source=perm_data['source'],
-                ))
+                data[partition_title][group_title].append(
+                    dict(
+                        title=perm_data['title'],
+                        description=perm_data['description'],
+                        source=perm_data['source'],
+                    )
+                )
 
         return PreJsonResult(data)
 
 
 class ResultPermissionsPack(BasePack):
-
-    u"""Набор действий для грида "Итоговые разрешения" окна редактирования."""
+    """Набор действий для грида "Итоговые разрешения" окна редактирования."""
 
     def __init__(self):
-        super(ResultPermissionsPack, self).__init__()
+        super().__init__()
         # ---------------------------------------------------------------------
 
         self.result_permissions_action = ResultPermissionsAction()
 
-        self.actions.extend((
-            self.result_permissions_action,
-        ))
+        self.actions.extend((self.result_permissions_action,))
         # ---------------------------------------------------------------------
 
         self.need_check_permission = True
@@ -747,11 +782,14 @@ class ResultPermissionsPack(BasePack):
         # ---------------------------------------------------------------------
 
     def declare_context(self, action):
-        result = super(ResultPermissionsPack, self).declare_context(action)
+        """Декларация контекста для экшна."""
+        result = super().declare_context(action)
 
         if action is self.result_permissions_action:
             result[get_pack_id(Pack)] = dict(type='int_or_none', default=None)
             result['role_permissions'] = dict(type='int_list', default=())
 
         return result
+
+
 # -----------------------------------------------------------------------------
