@@ -1,7 +1,3 @@
-# coding: utf-8
-from __future__ import absolute_import
-
-
 AUTH_CONTROLLER_URL = '/auth'
 AUTH_PACK_URL = ''
 LOGIN_PAGE_URL = '/login-page'
