@@ -1,5 +1,4 @@
-# coding: utf-8
-u"""Средства для реализации партиционирования таблиц в СУБД PostgreSQL.
+"""Средства для реализации партиционирования таблиц в СУБД PostgreSQL.
 
 В настоящее время поддерживается только помесячное разбиение таблиц БД на
 разделы.
@@ -29,59 +28,81 @@ u"""Средства для реализации партиционирован
 Подробнее о партиционировании можно почитать в дкоументации PostgreSQL
 (раздел 5.9).
 """
-from __future__ import absolute_import
 
-from contextlib import closing
-from os import path
-from time import sleep
-from types import MethodType
 import re
+from contextlib import (
+    closing,
+)
+from os import (
+    path,
+)
+from time import (
+    sleep,
+)
+from types import (
+    MethodType,
+)
+from typing import (
+    Optional,
+)
 
-from django.conf import settings
-from django.core.exceptions import ImproperlyConfigured
-from django.db import connections
-from django.db import router
-from django.db import transaction
-from django.db.models.options import Options
-from django.db.models.sql.compiler import cursor_iter
-from django.db.utils import DEFAULT_DB_ALIAS
-from django.utils.functional import cached_property
-from m3_django_compat import ModelOptions
-from m3_django_compat import commit_unless_managed
-from six.moves import map
-import six
+from django.conf import (
+    settings,
+)
+from django.core.exceptions import (
+    ImproperlyConfigured,
+)
+from django.db import (
+    connections,
+    router,
+)
+from django.db.models.sql.compiler import (
+    cursor_iter,
+)
+from django.db.utils import (
+    DEFAULT_DB_ALIAS,
+)
+from django.utils.functional import (
+    cached_property,
+)
 
-from educommon.django.db.observer import ModelObserverBase
+from m3_django_compat import (
+    ModelOptions,
+    commit_unless_managed,
+)
+
+from educommon.django.db.observer import (
+    ModelObserverBase,
+)
+from educommon.django.db.partitioning.const import (
+    CURSOR_ITERSIZE,
+    INSERT_CURSOR_ITERSIZE,
+    PARTITION_TRIGGERS_FUNCTIONS,
+)
 
 
 _MESSAGE_PREFIX = '[Partitioning] '
 
 
 def _check_system_settings(database_alias):
-    u"""Проверка конфигурации системы. Перечень проверок:
+    """Проверка конфигурации системы. Перечень проверок:
 
-        1. Указанный алиас БД есть в конфигурации системы.
-        2. Указанная БД управляется СУБД PostgreSQL.
+    1. Указанный алиас БД есть в конфигурации системы.
+    2. Указанная БД управляется СУБД PostgreSQL.
     """
     if database_alias not in settings.DATABASES:
-        raise ImproperlyConfigured(
-            _MESSAGE_PREFIX +
-            '"{0}" database not found.'.format(database_alias)
-        )
+        raise ImproperlyConfigured(f'{_MESSAGE_PREFIX}"{database_alias}" database not found.')
 
     database_engine = settings.DATABASES[database_alias]['ENGINE']
     if database_engine not in (
         'django.db.backends.postgresql_psycopg2',
         'django.db.backends.postgresql',
     ):
-        raise ImproperlyConfigured(
-            _MESSAGE_PREFIX +
-            'only PostgreSQL DBMS supported.'
-        )
+        raise ImproperlyConfigured(f'{_MESSAGE_PREFIX}only PostgreSQL DBMS supported.')
 
 
 def is_initialized(database_alias):
-    u"""Проверяет, проинициализированы ли средства партиционирования.
+    """Проверяет, проинициализированы ли средства партиционирования.
 
     :param str database_alias: Алиас БД, в которой будет проверяться наличие
         средств партиционирования.
@@ -90,33 +111,21 @@ def is_initialized(database_alias):
     """
     # Проверка наличия схемы partitioning.
     with closing(connections[database_alias].cursor()) as cursor:
-        cursor.execute(
-            "select 1 from pg_namespace where nspname = 'partitioning'"
-        )
+        cursor.execute("select 1 from pg_namespace where nspname = 'partitioning'")
         if cursor.fetchone() is None:
             return False
 
     # Проверка наличия всех функций схемы.
-    function_names = set((
-        'getattr',
-        'get_partition_name',
-        'set_partition_constraint',
-        'table_exists',
-        'is_table_partitioned',
-        'create_partition',
-        'before_insert',
-        'instead_of_insert',
-        'before_update',
-    ))
+    function_names = PARTITION_TRIGGERS_FUNCTIONS
     for function_name in function_names:
         with closing(connections[database_alias].cursor()) as cursor:
             cursor.execute(
-                "select 1 "
-                "from pg_proc proc "
-                "inner join pg_namespace ns on ns.oid = proc.pronamespace "
+                'select 1 '
+                'from pg_proc proc '
+                'inner join pg_namespace ns on ns.oid = proc.pronamespace '
                 "where proc.proname = %s and ns.nspname = 'partitioning' "
-                "limit 1",
-                [function_name]
+                'limit 1',
+                [function_name],
             )
             if cursor.fetchone() is None:
                 return False
@@ -125,6 +134,7 @@ def is_initialized(database_alias):
 
 
 def _execute_sql_file(database_alias, file_name, params=None):
+    """Выполняет SQL-скрипт из файла с подстановкой параметров."""
     cursor = connections[database_alias].cursor()
 
     file_path = path.join(path.dirname(__file__), file_name)
@@ -142,7 +152,7 @@ def _execute_sql_file(database_alias, file_name, params=None):
 
 
 def init(database_alias=DEFAULT_DB_ALIAS, force=False):
-    u"""Осуществляет инициализацию средств партиционирования таблиц БД.
+    """Осуществляет инициализацию средств партиционирования таблиц БД.
 
     Под средствами партиционирования понимается набор функций, создаваемых
     в указанной базе данных. С помощью этих функций реализуется автоматическое
@@ -157,16 +167,19 @@ def init(database_alias=DEFAULT_DB_ALIAS, force=False):
     _check_system_settings(database_alias)
 
     if not force and is_initialized(database_alias):
-        raise ImproperlyConfigured(
-            _MESSAGE_PREFIX + 'always initialized'
-        )
+        raise ImproperlyConfigured(f'{_MESSAGE_PREFIX}always initialized')
 
-    _execute_sql_file(database_alias, 'partitioning.sql', dict(
-        view_name_suffix=PartitioningObserver.view_name_suffix,
-    ))
+    _execute_sql_file(
+        database_alias,
+        'partitioning.sql',
+        dict(
+            view_name_suffix=PartitioningObserver.view_name_suffix,
+        ),
+    )
 
 
 def _get_model_params(model):
+    """Возвращает параметры модели: алиас БД, имя таблицы и имя PK-колонки."""
     database_alias = router.db_for_write(model)
     table_name = model._meta.db_table
     pk_column_name = model._meta.pk.name
@@ -175,28 +188,24 @@ def _get_model_params(model):
 
 
 def is_model_partitioned(model):
-    u"""Возвращает True, если для модели включено партиционирование.
+    """Возвращает True, если для модели включено партиционирование.
 
     :rtype: bool
     """
     database_alias, table_name, _ = _get_model_params(model)
 
     with closing(connections[database_alias].cursor()) as cursor:
-        cursor.execute(
-            "select 1 from pg_namespace where nspname = 'partitioning' limit 1"
-        )
+        cursor.execute("select 1 from pg_namespace where nspname = 'partitioning' limit 1")
         if cursor.fetchone() is None:
             return False
 
-        cursor.execute(
-            "select partitioning.is_table_partitioned(%s)",
-            (table_name,)
-        )
+        cursor.execute('select partitioning.is_table_partitioned(%s)', (table_name,))
+
         return cursor.fetchone()[0]
 
 
 def set_partitioning_for_model(model, column_name, force=False):
-    u"""Включает партиционирование указанной таблицы или модели.
+    """Включает партиционирование указанной таблицы или модели.
 
     Для включения партиционирования для указанной таблицы создаются триггеры,
     вызывающие функции управления партиционированием. Перед включением
@@ -210,7 +219,7 @@ def set_partitioning_for_model(model, column_name, force=False):
         значение будет определять раздел таблицы, в который будет помещена
         запись.
 
-    :raises django.db.models.fields.FieldDoesNotExist: если модель *model* не
+    :raises m3_django_compat.exceptions.FieldDoesNotExist: если модель *model* не
         содержит поля *column_name*
     """
     database_alias, table_name, pk_column_name = _get_model_params(model)
@@ -220,15 +229,13 @@ def set_partitioning_for_model(model, column_name, force=False):
     ModelOptions(model).get_field(column_name)
 
     if not force and not is_initialized(database_alias):
-        raise ImproperlyConfigured(
-            _MESSAGE_PREFIX + 'not initialized'
-        )
+        raise ImproperlyConfigured(f'{_MESSAGE_PREFIX}not initialized')
 
     _execute_sql_file(database_alias, 'triggers.sql', locals())
 
 
-def split_table(model, column_name, timeout=0):
-    u"""Переносит записи из разбиваемой таблицы в ее разделы.
+def split_table(model, column_name: str, timeout: float = 0, cursor_itersize: Optional[int] = None):
+    """Переносит записи из разбиваемой таблицы в ее разделы.
 
     Недостающие разделы будут созданы автоматически.
 
@@ -240,30 +247,28 @@ def split_table(model, column_name, timeout=0):
         запись.
     :param float timeout: Время ожидания в секундах  между переносом записей
         (можно использовать для снижения нагрузки на СУБД).
+    :param int cursor_itersize: Количество записей, попадающих в итератор курсора бд
+        при запросе разбиения таблиц.
 
-    :raises django.db.models.fields.FieldDoesNotExist: если модель *model* не
+    :raises m3_django_compat.exceptions.FieldDoesNotExist: если модель *model* не
         содержит поля *column_name*
     """
     database_alias, table_name, pk_column_name = _get_model_params(model)
 
+    if not cursor_itersize:
+        cursor_itersize = INSERT_CURSOR_ITERSIZE
+
     # для проверки наличия поля в модели
     ModelOptions(model).get_field(column_name)
 
     if not is_initialized(database_alias):
-        raise ImproperlyConfigured(
-            _MESSAGE_PREFIX + 'not initialized'
-        )
+        raise ImproperlyConfigured(f'{_MESSAGE_PREFIX}not initialized')
 
     if not is_model_partitioned(model):
-        raise ImproperlyConfigured(
-            _MESSAGE_PREFIX + 'not applyed for {table_name}'.format(**locals())
-        )
+        raise ImproperlyConfigured(f'{_MESSAGE_PREFIX}not applyed for {table_name}')
 
     if settings.DATABASES[database_alias]['DISABLE_SERVER_SIDE_CURSORS']:
-        raise ImproperlyConfigured(
-            _MESSAGE_PREFIX + 'split_table does not '
-                              'support DISABLE_SERVER_SIDE_CURSORS.'
-        )
+        raise ImproperlyConfigured(f'{_MESSAGE_PREFIX}split_table does not support DISABLE_SERVER_SIDE_CURSORS.')
 
     connection = connections[database_alias]
 
@@ -276,27 +281,29 @@ def split_table(model, column_name, timeout=0):
 
     move_cursor = connection.cursor()
 
-    results = cursor_iter(
-        ids_cursor, connection.features.empty_fetchmany_value, 1
-    )
+    results = cursor_iter(ids_cursor, connection.features.empty_fetchmany_value, 1, cursor_itersize)
     for rows in results:
-        pk_column_values = tuple(pkv for (pkv,) in rows)
+        # Если всего одна запись, то используем строку, чтобы не получать ошибку sql-запроса на обновление
+        if len(rows) == 1:
+            pk_column_values = f'{rows[0]}'.replace(',', '')
+        else:
+            pk_column_values = tuple(pkv for (pkv,) in rows)
         # Этот update выполняется для того, чтобы сработала триггерная
         # функция partitioning.before_update.
-        move_cursor.execute((
-            'update {table_name} '
-            'set {pk_column_name} = {pk_column_name} '
-            'where {pk_column_name} in {pk_column_values}'
-        ).format(**locals()))
-
-        commit_unless_managed(database_alias)
+        move_cursor.execute(
+            (
+                'update {table_name} '
+                'set {pk_column_name} = {pk_column_name} '
+                'where {pk_column_name} in {pk_column_values}'
+            ).format(**locals())
+        )
 
         if timeout:
             sleep(timeout)
 
 
-def clear_table(model, column_name, column_value, timeout=0):
-    u"""Удаление записей по условию.
+def clear_table(model, column_name: str, column_value: str, timeout=0, cursor_itersize: Optional[int] = None):
+    """Удаление записей по условию.
 
     С помощью данной команды удаляются записи из основной (не секционированной)
     таблицы, у которых значение в column_name меньше значения из column_value.
@@ -310,45 +317,50 @@ def clear_table(model, column_name, column_value, timeout=0):
         будут удаляться записи.
     :param float timeout: Время ожидания в секундах  между удалением 100
         записей (можно использовать для снижения нагрузки на СУБД).
+    :param int cursor_itersize: Количество записей, попадающих в итератор курсора бд
+        при запросе удаления таблиц.
     """
     database_alias, table_name, pk_column_name = _get_model_params(model)
 
+    if not cursor_itersize:
+        cursor_itersize = CURSOR_ITERSIZE
+
     connection = connections[database_alias]
 
     if settings.DATABASES[database_alias]['DISABLE_SERVER_SIDE_CURSORS']:
-        raise ImproperlyConfigured(
-            _MESSAGE_PREFIX + 'clear_table does not '
-                              'support DISABLE_SERVER_SIDE_CURSORS.'
-        )
+        raise ImproperlyConfigured(f'{_MESSAGE_PREFIX}clear_table does not support DISABLE_SERVER_SIDE_CURSORS.')
 
     ids_cursor = connection.chunked_cursor()
     ids_cursor.execute(
         # сырой SQL используется для того, чтобы извлечь только записи
         # из родительской таблицы без записей, уже размещенных в разделах
-        "select {pk_column_name} from only {table_name} "
-        "where {column_name} < '{column_value}'".format(**locals())
+        "select {pk_column_name} from only {table_name} where {column_name} < '{column_value}'".format(**locals())
     )
 
     delete_cursor = connection.cursor()
 
     results = cursor_iter(
-        ids_cursor, connection.features.empty_fetchmany_value, 1
+        ids_cursor,
+        connection.features.empty_fetchmany_value,
+        1,
+        cursor_itersize,
     )
     for rows in results:
-        pk_column_values = tuple(pkv for (pkv,) in rows)
-        delete_cursor.execute((
-            'delete from {table_name} '
-            'where {pk_column_name} in {pk_column_values}'
-        ).format(**locals()))
-
-        commit_unless_managed(database_alias)
+        # Если всего одна запись, то используем строку, чтобы не получать ошибку sql-запроса на удаление
+        if len(rows) == 1:
+            pk_column_values = f'{rows[0]}'.replace(',', '')
+        else:
+            pk_column_values = tuple(pkv for (pkv,) in rows)
+        delete_cursor.execute(
+            ('delete from {table_name} where {pk_column_name} in {pk_column_values}').format(**locals())
+        )
 
         if timeout:
             sleep(timeout)
 
 
 def get_model_partitions(model):
-    u"""Возвращает названия разделов таблицы.
+    """Возвращает названия разделов таблицы.
 
     :param model: Модель, записи которой перенесены в разделы. Алиас
         используемой БД определяется с помощью метода db_for_write роутера
@@ -361,20 +373,17 @@ def get_model_partitions(model):
     cursor = connection.cursor()
 
     cursor.execute(
-        "select inhrelid::regclass::text as partition_name "
-        "from pg_inherits "
+        'select inhrelid::regclass::text as partition_name '
+        'from pg_inherits '
         "where inhparent = '{}'::regclass::oid "
-        "order by partition_name"
-        .format(table_name)
-    )
-    return tuple(
-        partition_name
-        for (partition_name,) in cursor
+        'order by partition_name'.format(table_name)
     )
 
+    return tuple(partition_name for (partition_name,) in cursor)
+
 
 def reset_partition_constraints(model, column_name, partition_name):
-    u"""Переустанавливает ограничения для указанного раздела.
+    """Переустанавливает ограничения для указанного раздела.
 
     :param model: Модель, записи которой перенесены в разделы. Алиас
         используемой БД определяется с помощью метода db_for_write роутера
@@ -392,15 +401,14 @@ def reset_partition_constraints(model, column_name, partition_name):
     cursor = connection.cursor()
 
     cursor.execute(
-        'select partitioning.set_partition_constraint(%s, %s, %s, %s)',
-        (partition_name, column_name, year, month)
+        'select partitioning.set_partition_constraint(%s, %s, %s, %s)', (partition_name, column_name, year, month)
     )
 
     commit_unless_managed(database_alias)
 
 
 def drop_partitions_before_date(model, date):
-    u"""Удаление старых партиций модели вплоть до месяца переданной даты.
+    """Удаление старых партиций модели вплоть до месяца переданной даты.
 
     :param Model: модель
     :type Model: django.db.models.base.ModelBase
@@ -410,23 +418,31 @@ def drop_partitions_before_date(model, date):
     if is_model_partitioned(model):
         database_alias, table_name, _ = _get_model_params(model)
         all_partitions = get_model_partitions(model)
-        filter_partition_name = table_name + '_y{}m{}'.format(
-            date.year, date.strftime('%m')
-        )
-        filtered_partitions = filter(
-            lambda p: (p <= filter_partition_name), all_partitions
-        )
+        filter_partition_name = f'{table_name}_y{date.year}m{date.strftime("%m")}'
+        filtered_partitions = filter(lambda p: (p <= filter_partition_name), all_partitions)
         connection = connections[database_alias]
         with connection.cursor() as cursor:
             for partition in filtered_partitions:
-                cursor.execute(
-                    'DROP TABLE IF EXISTS {};'.format(partition)
-                )
+                cursor.execute('DROP TABLE IF EXISTS {};'.format(partition))
+
+
+def set_partitioned_function_search_path(database_alias: str, schema_names: Optional[str] = None):
+    """ "Проставляет параметры поиска для существующих функций партицирования.
+
+    Это необходимо для корректной работы с таблицами к которым обращаются как к внешним через postgres_fdw.
+    """
+    schema_names = schema_names or 'public'
+    _execute_sql_file(
+        database_alias,
+        'partitioning_set_search_path.sql',
+        dict(
+            schema_names=schema_names,
+        ),
+    )
 
 
 class PartitioningObserver(ModelObserverBase):
-
-    u"""Оптимизирует операции вставки в партиционированные таблицы.
+    """Оптимизирует операции вставки в партиционированные таблицы.
 
     При добавлении записей в партиционированную таблицу добавление происходит
     следующим образом:
@@ -452,13 +468,11 @@ class PartitioningObserver(ModelObserverBase):
 
     @cached_property
     def _partitioning_ready(self):
-        return {
-            database_alias: is_initialized(database_alias)
-            for database_alias in connections
-        }
+        """Кэширует информацию о том, проинициализировано ли партиционирование в БД."""
+        return {database_alias: is_initialized(database_alias) for database_alias in connections}
 
     def _is_observable(self, model):
-        u"""Возвращает True только для моделей с включенным партиционированием.
+        """Возвращает True только для моделей с включенным партиционированием.
 
         :rtype: bool
         """
@@ -471,7 +485,7 @@ class PartitioningObserver(ModelObserverBase):
         return self.__models[model]
 
     def pre_save(self, instance, context, **kwargs):
-        u"""Оборачивает метод _save_table объекта для подмены имени таблицы.
+        """Оборачивает метод _save_table объекта для подмены имени таблицы.
 
         После замены метода ``_save_table`` ДО вызова оригинального метода
         в ``instance._meta.db_table`` записывается имя представления, через
@@ -490,10 +504,10 @@ class PartitioningObserver(ModelObserverBase):
                 finally:
                     self._meta.db_table = db_table
 
-            instance._save_table = six.create_bound_method(wrapper, instance)
+            instance._save_table = MethodType(wrapper, instance)
 
     def post_save(self, instance, context, **kwargs):
-        u"""Восстанавливает метод _save_table объекта."""
+        """Восстанавливает метод _save_table объекта."""
 
         if '_save_table' in instance.__dict__:
             del instance.__dict__['_save_table']
