@@ -1,28 +1,39 @@
-# coding: utf-8
 """Валидаторы для простых (текстовых, числовых и т.п.) полей модели Django."""
-from __future__ import absolute_import
-from __future__ import unicode_literals
 
-from datetime import datetime
-from functools import partial
-from itertools import cycle
 import re
+from datetime import (
+    datetime,
+)
+from functools import (
+    partial,
+)
+from itertools import (
+    cycle,
+)
 
-from django.core.exceptions import NON_FIELD_ERRORS
-from django.core.exceptions import ValidationError
-from django.core.validators import DecimalValidator
-from django.core.validators import RegexValidator
-from django.utils.deconstruct import deconstructible
-from six.moves import range
-from six.moves import zip
 import magic
-import six
+from django.core.exceptions import (
+    NON_FIELD_ERRORS,
+    ValidationError,
+)
+from django.core.validators import (
+    DecimalValidator,
+    RegexValidator,
+)
+from django.utils.deconstruct import (
+    deconstructible,
+)
 
-from educommon.utils.misc import get_mime_type_for_extension
-
-from . import IModelValidator
-from . import validate_value
-from ..utils import get_original_object
+from educommon.django.db.utils import (
+    get_original_object,
+)
+from educommon.django.db.validators import (
+    IModelValidator,
+    validate_value,
+)
+from educommon.utils.misc import (
+    get_mime_type_for_extension,
+)
 
 
 # =============================================================================
@@ -40,17 +51,18 @@ class SNILSValidator(RegexValidator):
         содержит значение, несоответствующее формату СНИЛС, либо контрольное
         число некорректно.
     """
+
     regex = _snils_re.pattern
     message = 'СНИЛС должен быть в формате ###-###-### ##'
     flags = _snils_re.flags
 
     def __call__(self, value):
-        super(SNILSValidator, self).__call__(value)
+        super().__call__(value)
         snils_checksum_validator(value)
 
 
 def snils_checksum_validator(value):
-    value = six.text_type(value)
+    value = str(value)
 
     if value[:11] <= '001-001-998':
         return
@@ -61,8 +73,7 @@ def snils_checksum_validator(value):
     if summa > 101:
         summa %= 101
 
-    if (summa < 100 and summa != checksum or
-            summa in (100, 101) and checksum != 0):
+    if summa < 100 and summa != checksum or summa in (100, 101) and checksum != 0:
         raise ValidationError('не пройдена проверка контрольного числа')
 
 
@@ -71,7 +82,8 @@ regex_snils_validator = SNILSValidator()
 
 # для совместимости со старым валидатором-функцией
 def snils_validator(value):
-    value = six.text_type(value)
+    """Проверка корректности СНИЛС с помощью регулярного выражения и контрольной суммы."""
+    value = str(value)
 
     regex_snils_validator(value)
 
@@ -85,6 +97,7 @@ is_snils_valid = partial(validate_value, validator=snils_validator)
 
 
 def _check_inn_checksum(coefficients, numbers, checksum):
+    """Проверка контрольного числа ИНН с использованием весовых коэффициентов."""
     summa = sum(c * n for c, n in zip(coefficients, numbers))
     if summa % 11 % 10 != checksum:
         raise ValidationError('Не пройдена проверка контрольного числа')
@@ -99,14 +112,12 @@ def inn10_validator(value):
         содержит значение, несоответствующее формату ИНН, либо не пройдена
         проверка контрольного числа.
     """
-    value = six.text_type(value)
+    value = str(value)
 
     if len(value) != 10 or not value.isdigit():
         raise ValidationError('ИНН должен быть 10-ти значным числом')
 
-    _check_inn_checksum((2, 4, 10, 3, 5, 9, 4, 6, 8),
-                        (int(ch) for ch in value[:-1]),
-                        int(value[-1]))
+    _check_inn_checksum((2, 4, 10, 3, 5, 9, 4, 6, 8), (int(ch) for ch in value[:-1]), int(value[-1]))
 
 
 def inn12_validator(value):
@@ -118,18 +129,14 @@ def inn12_validator(value):
         содержит значение, несоответствующее формату ИНН, либо не пройдена
         проверка контрольного числа.
     """
-    value = six.text_type(value)
+    value = str(value)
 
     if len(value) != 12 or not value.isdigit():
         raise ValidationError('ИНН должен быть 12-ти значным числом')
 
-    _check_inn_checksum((7, 2, 4, 10, 3, 5, 9, 4, 6, 8),
-                        (int(ch) for ch in value[:-2]),
-                        int(value[-2]))
+    _check_inn_checksum((7, 2, 4, 10, 3, 5, 9, 4, 6, 8), (int(ch) for ch in value[:-2]), int(value[-2]))
 
-    _check_inn_checksum((3, 7, 2, 4, 10, 3, 5, 9, 4, 6, 8),
-                        (int(ch) for ch in value[:-1]),
-                        int(value[-1]))
+    _check_inn_checksum((3, 7, 2, 4, 10, 3, 5, 9, 4, 6, 8), (int(ch) for ch in value[:-1]), int(value[-1]))
 
 
 def inn_validator(value):
@@ -142,7 +149,7 @@ def inn_validator(value):
         содержит значение, несоответствующее формату ИНН, либо не пройдена
         проверка контрольного числа.
     """
-    value = six.text_type(value)
+    value = str(value)
 
     if len(value) not in (10, 12) or not value.isdigit():
         raise ValidationError('ИНН должен быть 10-ти или 12-ти значным числом')
@@ -165,7 +172,7 @@ is_inn12_valid = partial(validate_value, validator=inn12_validator)
 
 def kpp_validator(value):
     """Валидатор для КПП (кода причины постановки на налоговый учет)."""
-    value = six.text_type(value)
+    value = str(value)
 
     if len(value) != 9 or not value.isdigit():
         raise ValidationError('КПП должен быть 9-ти значным числом')
@@ -196,19 +203,13 @@ def checksum_pr_50_1_024(value):
     Если в случае повторного расчета остаток от деления вновь сохраняется
     равным 10, то значение контрольного числа проставляется равным 0.
     """
-    summa = sum(
-        int(digit) * weight
-        for digit, weight in zip(value, cycle(list(range(1, 11))))
-    )
+    summa = sum(int(digit) * weight for digit, weight in zip(value, cycle(list(range(1, 11)))))
 
     remainder = summa % 11
     if remainder < 10:
         result = remainder
     else:
-        summa = sum(
-            int(digit) * weight
-            for digit, weight in zip(value, cycle(list(range(3, 13))))
-        )
+        summa = sum(int(digit) * weight for digit, weight in zip(value, cycle(list(range(3, 13)))))
         remainder = summa % 11
         if remainder < 10:
             result = remainder
@@ -227,7 +228,7 @@ def okato_validator(value):
     .. seealso::
        `Контрольное число ОКАТО <http://kontragent.info/articles/okato>`_
     """
-    value = six.text_type(value)
+    value = str(value)
 
     if not value.isdigit():
         raise ValidationError('ОКАТО должен состоять только из цифр')
@@ -239,9 +240,7 @@ def okato_validator(value):
             raise ValidationError('Не пройдена проверка контрольного числа')
 
     elif value_length not in (2, 5, 8, 11):
-        raise ValidationError(
-            'Код ОКАТО должен состоять из 2, 5, 8 или 11 цифр'
-        )
+        raise ValidationError('Код ОКАТО должен состоять из 2, 5, 8 или 11 цифр')
 
 
 is_okato_valid = partial(validate_value, validator=okato_validator)
@@ -252,16 +251,14 @@ def oktmo_validator(value):
 
     ОКТМО - Общероссийский классификатор территорий муниципальных образований.
     """
-    value = six.text_type(value)
+    value = str(value)
 
     if not value.isdigit():
         raise ValidationError('ОКТМО должен состоять только из цифр')
 
     value_length = len(value)
     if value_length not in (2, 5, 8, 11):
-        raise ValidationError(
-            'ОКТМО не может состоять из {} цифр'.format(value_length)
-        )
+        raise ValidationError('ОКТМО не может состоять из {} цифр'.format(value_length))
 
 
 is_oktmo_valid = partial(validate_value, validator=oktmo_validator)
@@ -272,7 +269,7 @@ def okpo_validator(value):
 
     ОКПО - Общероссийский классификатор предприятий и организаций.
     """
-    value = six.text_type(value)
+    value = str(value)
 
     if not value.isdigit():
         raise ValidationError('ОКПО должен состоять только из цифр')
@@ -294,7 +291,7 @@ def _check_ogrn_checksum(value):
     """
     value_length = len(value)  # количество цифр в ОГРН
     divisor = value_length - 2  # делитель для вычисления контрольного числа
-    number = int(value[:value_length - 1])  # ОГРН
+    number = int(value[: value_length - 1])  # ОГРН
     control_number = int(value[-1])  # контрольное число
 
     if number % divisor % 10 != control_number:
@@ -302,16 +299,17 @@ def _check_ogrn_checksum(value):
 
 
 def _ogrn_validator(value, valid_length, title):
-    value = six.text_type(value)
+    """Общая логика для проверки ОГРН и ОГРНИП.
+
+    Проверяет длину и контрольное число.
+    """
+    value = str(value)
 
     if not value.isdigit():
         raise ValidationError('ОГРН должен состоять только из цифр')
     if len(value) not in valid_length:
         raise ValidationError(
-            '{} должен состоять из {} цифр!'.format(
-                title,
-                ' или '.join(six.text_type(l) for l in valid_length)
-            )
+            '{} должен состоять из {} цифр!'.format(title, ' или '.join(str(length) for length in valid_length))
         )
 
     _check_ogrn_checksum(value)
@@ -356,16 +354,14 @@ def okved_validator(value):
 
     ОКВЭД - Общероссийский классификатор видов экономической деятельности.
     """
-    value = six.text_type(value)
+    value = str(value)
 
     if not value.isdigit():
         raise ValidationError('ОКВЭД должен состоять только из цифр')
 
     value_length = len(value)
     if value_length < 2 or 6 < value_length:
-        raise ValidationError(
-            'Код ОКВЭД не может состоять из {} цифр'.format(value_length)
-        )
+        raise ValidationError('Код ОКВЭД не может состоять из {} цифр'.format(value_length))
 
 
 is_okved_valid = partial(validate_value, validator=okved_validator)
@@ -379,7 +375,7 @@ def okopf_validator(value):
 
     ОКОПФ - Общероссийский классификатор организационно-правовых форм.
     """
-    value = six.text_type(value)
+    value = str(value)
 
     if not value.isdigit():
         raise ValidationError('ОКОПФ должен состоять только из цифр')
@@ -397,7 +393,7 @@ def okfs_validator(value):
 
     ОКФС - Общероссийский классификатор форм собственности.
     """
-    value = six.text_type(value)
+    value = str(value)
 
     if not value.isdigit():
         raise ValidationError('ОКФС должен состоять только из цифр')
@@ -424,27 +420,18 @@ def validate_file_mime_type(file, allowed_mime_types):
     file.seek(0, 0)
     file_mime_type = magic.from_buffer(file.read(), mime=True)
     if file_mime_type not in allowed_mime_types:
-        raise ValidationError(
-            'Mime type файла не соотвествует допустимым в системе'
-        )
+        raise ValidationError('Mime type файла не соотвествует допустимым в системе')
 
 
 @deconstructible
-class FileMimeTypeValidator(object):
-
+class FileMimeTypeValidator:
     """Валидатор для FileField модели проверяющий mimetype файла."""
 
-    message = (
-        'Mime type файла не допустим для загрузки в системе.'
-    )
+    message = 'Mime type файла не допустим для загрузки в системе.'
     code = 'invalid_mimetype'
 
     def __init__(self, allowed_extensions, message=None, code=None):
-        self.allowed_extensions = [
-            allowed_extension.lower()
-            for allowed_extension
-            in allowed_extensions
-        ]
+        self.allowed_extensions = [allowed_extension.lower() for allowed_extension in allowed_extensions]
 
         self.allowed_mime_types = set(
             get_mime_type_for_extension(extension)
@@ -536,7 +523,6 @@ class OptionalFieldValidator(IModelValidator):
 
 
 class RequiredBooleanValidator(OptionalFieldValidator):
-
     """Валидатор обязательного поля ``BooleanField``.
 
     Пример:
@@ -545,7 +531,9 @@ class RequiredBooleanValidator(OptionalFieldValidator):
 
         class Model(BaseModel):
             accept_rules = models.BooleanField(...)
-            validators = [RequiredBooleanValidator('accept_rules'),]
+            validators = [
+                RequiredBooleanValidator('accept_rules'),
+            ]
     """
 
     def __init__(self, field_name, **kwargs):
@@ -553,7 +541,7 @@ class RequiredBooleanValidator(OptionalFieldValidator):
 
         :param str field_name: имя валидируемого поля
         """
-        super(RequiredBooleanValidator, self).__init__(field_name, **kwargs)
+        super().__init__(field_name, **kwargs)
         self.empty_values = (False,)
 
     def _need_check(self, instance):
@@ -580,9 +568,12 @@ class RequiredFieldValidator(OptionalFieldValidator):
             # должно быть обязательным
             employee = models.ForeignKey(
                 'employee.Employee',
-                null=True, blank=True,
+                null=True,
+                blank=True,
             )
-            validators = [RequiredFieldValidator('employee'),]
+            validators = [
+                RequiredFieldValidator('employee'),
+            ]
     """
 
     def _need_check(self, instance):
@@ -598,7 +589,6 @@ class RequiredFieldValidator(OptionalFieldValidator):
 
 
 class UnchangeableFieldValidator(IModelValidator):
-
     """Валидатор неизменяемого поля.
 
     При редактировании объекта, если изменяется поле ``field_name``,
@@ -610,7 +600,9 @@ class UnchangeableFieldValidator(IModelValidator):
 
         class Model(BaseModel):
             type = models.BooleanField(...)
-            validators = [UnchangeableFieldValidator('type'),]
+            validators = [
+                UnchangeableFieldValidator('type'),
+            ]
 
     """
 
@@ -633,12 +625,9 @@ class UnchangeableFieldValidator(IModelValidator):
 
         :rtype: str
         """
-        verbose_name = instance._meta.get_field(
-            self.field_name
-        ).verbose_name
-        return 'Поле "{}" не доступно для редактирования.'.format(
-            verbose_name
-        )
+        verbose_name = instance._meta.get_field(self.field_name).verbose_name
+
+        return 'Поле "{}" не доступно для редактирования.'.format(verbose_name)
 
     def clean(self, instance, errors):
         """Проверка редактирования поля ``field_name``.
@@ -660,7 +649,6 @@ class UnchangeableFieldValidator(IModelValidator):
 
 
 class DuplicationValidator(IModelValidator):
-
     """Валидатор уникальности объекта.
 
     Используется для объектов, уникальность которых нельзя проверить
@@ -725,11 +713,8 @@ class DuplicationValidator(IModelValidator):
 
         :rtype: str
         """
-        return (
-            'В системе уже существует {} с такими же значениями полей {}.'
-        ).format(
-            instance._meta.verbose_name,
-            ', '.join(self._get_field_names(instance))
+        return ('В системе уже существует {} с такими же значениями полей {}.').format(
+            instance._meta.verbose_name, ', '.join(self._get_field_names(instance))
         )
 
     def _get_base_query(self, instance):
@@ -753,9 +738,7 @@ class DuplicationValidator(IModelValidator):
         :type errors: collections.OrderedDict
         """
         original = get_original_object(instance)
-        query = self._get_base_query(instance).filter(
-            self._get_duplication_params(instance)
-        )
+        query = self._get_base_query(instance).filter(self._get_duplication_params(instance))
 
         if original:
             query = query.exclude(id=instance.id)
@@ -765,12 +748,10 @@ class DuplicationValidator(IModelValidator):
 
 
 class SingleErrorDecimalValidator(DecimalValidator):
-
     """Кастомный класс валидации Decimal поля модели."""
 
     def __init__(self, max_digits, decimal_places):
-        super(SingleErrorDecimalValidator, self).__init__(
-            max_digits, decimal_places)
+        super().__init__(max_digits, decimal_places)
         self.max_whole_digits = max_digits - decimal_places
 
     def __call__(self, value):
@@ -799,8 +780,11 @@ class SingleErrorDecimalValidator(DecimalValidator):
                 code='max_decimal_places',
                 params={'max': self.decimal_places},
             )
-        if (self.max_digits is not None and self.decimal_places is not None and
-                whole_digits > (self.max_digits - self.decimal_places)):
+        if (
+            self.max_digits is not None
+            and self.decimal_places is not None
+            and whole_digits > (self.max_digits - self.decimal_places)
+        ):
             raise ValidationError(
                 self.messages['max_whole_digits'],
                 code='max_whole_digits',
@@ -812,13 +796,14 @@ class SingleErrorDecimalValidator(DecimalValidator):
 # Валидаторы персональных данных
 # =============================================================================
 
+
 class FIOValidator(RegexValidator):
     regex = r'(^$)|(^[a-zA-Zа-яА-ЯёЁ]([\s-]?[a-zA-Zа-яА-ЯёЁ])*$)'
 
 
-def date_range_validator(minimum=None, maximum=None,
-                         range_message=None, min_message=None,
-                         max_message=None, date_format='%d.%m.%Y'):
+def date_range_validator(
+    minimum=None, maximum=None, range_message=None, min_message=None, max_message=None, date_format='%d.%m.%Y'
+):
     """Валидатор даты. Возвращает функцию, в которую должен быть помещен один
     аргумент: проверяемое значение
     :param minimum: значение, меньше которого value быть не должно;
@@ -848,11 +833,9 @@ def date_range_validator(minimum=None, maximum=None,
     :return: функция, в которую передается проверяемое значение и которая ведет
     себя как обычный валидатор поля Django
     """
-    assert minimum is not None or maximum is not None, (
-        'Необходимо определелить границы для валидатора дат')
+    assert minimum is not None or maximum is not None, 'Необходимо определелить границы для валидатора дат'
 
-    range_message = (range_message or (
-        'Значение %(val)s не входит в диапазон %(min)s-%(max)s'))
+    range_message = range_message or ('Значение %(val)s не входит в диапазон %(min)s-%(max)s')
     min_message = min_message or 'Значение %(val)s меньше, чем %(min)s'
     max_message = max_message or 'Значение %(val)s больше %(max)s'
 
@@ -867,8 +850,9 @@ def date_range_validator(minimum=None, maximum=None,
     max_date = maximum or datetime.max.date()
     date_format = date_format
 
-    return partial(_date_range_validator, min_date=min_date, max_date=max_date,
-                   message=message, date_format=date_format)
+    return partial(
+        _date_range_validator, min_date=min_date, max_date=max_date, message=message, date_format=date_format
+    )
 
 
 def _date_range_validator(value, min_date, max_date, message, date_format):
@@ -886,12 +870,14 @@ def _date_range_validator(value, min_date, max_date, message, date_format):
     :raises ValidationError
     """
     # должны быть все аргументы
-    assert all([
-        min_date is not None,
-        max_date is not None,
-        message is not None,
-        date_format is not None,
-    ]), 'Все аргументы должны быть указаны (см. сигнатуру функции)'
+    assert all(
+        [
+            min_date is not None,
+            max_date is not None,
+            message is not None,
+            date_format is not None,
+        ]
+    ), 'Все аргументы должны быть указаны (см. сигнатуру функции)'
 
     if isinstance(value, datetime):
         value = value.date()
@@ -906,9 +892,7 @@ def _date_range_validator(value, min_date, max_date, message, date_format):
     }
 
     if not _min <= value <= _max:
-        raise ValidationError(
-            message % message_values
-        )
+        raise ValidationError(message % message_values)
 
 
 class HouseValidator(RegexValidator):
@@ -923,14 +907,30 @@ class HouseValidator(RegexValidator):
     Эти дома относятся к "специальным" зданиям, хоз. помещениям на закрытых
     территориях (заводы, склады), гаражам и т.д.
     Если нужно будет, что бы они так же считались валидными,
-    то регулярку нужно будет расширить до '^[0-9IVXа-яё/"_,.-]{1,20}$'
+    то регулярку нужно будет расширить до
+    '^(?=.{,20}$)([0-9IVXА-ЯЁа-яё"/_,.-]{1,} ?){1,}\b$'
     """
-    regex = re.compile(r'^[0-9а-яё/"_,.-]{0,12}$', re.IGNORECASE | re.UNICODE)
+
+    regex = re.compile(r'^(?=.{,12}$)([0-9а-яё"/_,.-]{1,} ?){1,}\b$', re.IGNORECASE | re.UNICODE)
     message = 'Неверно указан номер дома'
 
 
+regex_house_validator = HouseValidator()
+
+
+def house_validator(value):
+    """Функция для валидации номера дома."""
+    value = str(value)
+
+    regex_house_validator(value)
+
+
+is_house_number_valid = partial(validate_value, validator=house_validator)
+
+
 class BuildingValidator(RegexValidator):
     """Валидатор номера корпуса дома."""
+
     regex = re.compile(r'^[0-9а-яё/_.-]{0,10}$', re.IGNORECASE | re.UNICODE)
     message = 'Неверно указан корпус дома'
 
@@ -953,7 +953,8 @@ regex_doc_type_validator = DocumentTypeValidator()
 
 
 def doc_type_validator(value):
-    value = six.text_type(value)
+    """Функция для валидации строки с типом документа."""
+    value = str(value)
 
     regex_doc_type_validator(value)
 
@@ -972,14 +973,10 @@ class PassportNumberValidator(RegexValidator):
 
 
 class DocumentSeriesValidator(RegexValidator):
-    regex = (
-        r'(^$)|(^[a-zA-Zа-яА-ЯёЁ\d]([\s|\-|\.|\,|\\|\/]?[a-zA-Zа-яА-ЯёЁ\d])*$)'
-    )
+    regex = r'(^$)|(^[a-zA-Zа-яА-ЯёЁ\d]([\s|\-|\.|\,|\\|\/]?[a-zA-Zа-яА-ЯёЁ\d])*$)'
     message = 'Неверно задана серия документа'
 
 
 class DocumentNumberValidator(RegexValidator):
-    regex = (
-        r'(^$)|(^[a-zA-Zа-яА-ЯёЁ\d]([\s|\-|\.|\,|\\|\/]?[a-zA-Zа-яА-ЯёЁ\d])*$)'
-    )
+    regex = r'(^$)|(^[a-zA-Zа-яА-ЯёЁ\d]([\s|\-|\.|\,|\\|\/]?[a-zA-Zа-яА-ЯёЁ\d])*$)'
     message = 'Неверно задан номер документа'
