@@ -1,32 +1,51 @@
-# coding: utf-8
-u"""Вспомогательные средства для работы с компонентами M3."""
-from __future__ import absolute_import
+"""Вспомогательные средства для работы с компонентами M3."""
 
-from collections import defaultdict
-from functools import wraps
 import inspect
 import sys
+from functools import (
+    wraps,
+)
 
-from django.core.exceptions import NON_FIELD_ERRORS
-from django.core.exceptions import ValidationError as DjangoValidationError
-from django.db.models.base import Model
-from django.db.models.base import ModelBase
-from django.db.transaction import atomic
-from django.utils.encoding import force_text
-from m3.actions import Action
-from m3.actions import ActionPack
-from m3.actions import ControllerCache
-from objectpack.exceptions import ValidationError as ObjectPackValidationError
-from objectpack.models import ModelProxy
-from objectpack.models import ModelProxyMeta
-from objectpack.observer.base import ObservableController
-import six
+from django.core.exceptions import (
+    NON_FIELD_ERRORS,
+    ValidationError as DjangoValidationError,
+)
+from django.db.models.base import (
+    Model,
+    ModelBase,
+)
+from django.db.transaction import (
+    atomic,
+)
+from django.utils.encoding import (
+    force_str,
+)
 
-from educommon import ioc
-from educommon.utils.misc import NoOperationCM
+from m3.actions import (
+    Action,
+    ActionPack,
+    ControllerCache,
+)
+from objectpack.exceptions import (
+    ValidationError as ObjectPackValidationError,
+)
+from objectpack.models import (
+    ModelProxy,
+    ModelProxyMeta,
+)
+from objectpack.observer.base import (
+    ObservableController,
+)
+
+from educommon import (
+    ioc,
+)
+from educommon.utils.misc import (
+    NoOperationCM,
+)
 
 
-def convert_validation_error_to(exc, new_line=u'<br/>', model=None):
+def convert_validation_error_to(exc, new_line='<br/>', model=None):
     """Декоратор, преобразующий исключение
     django.core.exceptions.ValidationError, генерируемое в декорируемой
     функции, в исключение, указанное в аргументе exc путем объединения всех
@@ -46,7 +65,7 @@ def convert_validation_error_to(exc, new_line=u'<br/>', model=None):
         ValidationError
     :type exc: subclass of Exception
 
-    :param unicode new_line: разделитель строк в сообщении об ошибке
+    :param str new_line: разделитель строк в сообщении об ошибке
 
     :param model: Модель, в которой осуществляется валидация. Должна
         использоваться в тех случаях, когда исключение ValidationError
@@ -54,6 +73,7 @@ def convert_validation_error_to(exc, new_line=u'<br/>', model=None):
         Если аргумент указан, то данные будут извлекаться именно из этой
         модели.
     """
+
     def get_model_meta(error):
         if model is not None:
             return model._meta
@@ -67,35 +87,28 @@ def convert_validation_error_to(exc, new_line=u'<br/>', model=None):
         if 'self' not in error_frame.f_locals:
             raise
         model_instance = error_frame.f_locals['self']
+
         return model_instance._meta
 
     def get_messages_from_dict(model_meta, data):
         result = []
-        for field_name, field_errors in six.iteritems(data):
+        for field_name, field_errors in data.items():
             if field_name == NON_FIELD_ERRORS:
-                result.append(
-                    new_line.join(
-                        u'- {0}'.format(err) for err in field_errors
-                    )
-                )
+                result.append(new_line.join('- {0}'.format(err) for err in field_errors))
             else:
                 model_field = model_meta.get_field(field_name)
-                verbose_name = (model_field.verbose_name or u'')
-                result.append(new_line.join(
-                    u'- {0}: {1}'.format(verbose_name, err)
-                    for err in field_errors
-                ))
+                verbose_name = model_field.verbose_name or ''
+                result.append(new_line.join('- {0}: {1}'.format(verbose_name, err) for err in field_errors))
+
         return result
 
     def get_messages_from_list(messages):
-        result = [
-            u'- ' + message
-            for message in messages
-        ]
+        result = ['- ' + message for message in messages]
+
         return result
 
     assert issubclass(exc, Exception), type(exc)
-    new_line = six.text_type(new_line)
+    new_line = str(new_line)
 
     def decorator(func):
         assert inspect.ismethod(func) or inspect.isfunction(func)
@@ -108,13 +121,12 @@ def convert_validation_error_to(exc, new_line=u'<br/>', model=None):
                 model_meta = get_model_meta(e)
 
                 if hasattr(e, 'message_dict'):
-                    title = u'На форме имеются некорректно заполненные поля:'
-                    messages = [title] + get_messages_from_dict(model_meta,
-                                                                e.message_dict)
+                    title = 'На форме имеются некорректно заполненные поля:'
+                    messages = [title] + get_messages_from_dict(model_meta, e.message_dict)
                 else:
-                    title = u'При проверке данных найдены ошибки:'
+                    title = 'При проверке данных найдены ошибки:'
                     messages = [title] + get_messages_from_list(e.messages)
-                messages.insert(1, u'')
+                messages.insert(1, '')
 
                 raise exc(new_line.join(messages))
 
@@ -123,9 +135,8 @@ def convert_validation_error_to(exc, new_line=u'<br/>', model=None):
     return decorator
 
 
-class ModelProxyValidationMixin(object):
-
-    u"""Примесь для составных прокси-моделей objectpack'а.
+class ModelProxyValidationMixin:
+    """Примесь для составных прокси-моделей objectpack'а.
 
     Добавляет к *objectpack.models.ModelProxy* возможность валидации данных
     перед сохранением. Валидация осуществляется, как и в моделях Django, путем
@@ -137,13 +148,11 @@ class ModelProxyValidationMixin(object):
     def __update_error_dict(self, error, errors, model_name):
         model_errors = error.update_error_dict({})
 
-        for field_name, messages in six.iteritems(model_errors):
-
+        for field_name, messages in model_errors.items():
             # В зависимости от версии Django в messages могут быть
             # как сообщения в виде строк, так и экземпляры ValidationError,
             # поэтому приводим его к списку, содержащему только строки
-            messages = sum([m.messages if isinstance(
-                m, DjangoValidationError) else [m] for m in messages], [])
+            messages = sum([m.messages if isinstance(m, DjangoValidationError) else [m] for m in messages], [])
 
             if field_name != NON_FIELD_ERRORS:
                 full_field_name = '.'.join((model_name, field_name))
@@ -162,7 +171,7 @@ class ModelProxyValidationMixin(object):
                     # объект будет создан при сохранении составной
                     # модели.
                     field = self._meta.get_field(full_field_name)
-                    if force_text(field.error_messages['null']) in messages:
+                    if force_str(field.error_messages['null']) in messages:
                         messages.remove(field.error_messages['null'])
                     if not messages:
                         continue
@@ -174,7 +183,7 @@ class ModelProxyValidationMixin(object):
         return errors
 
     def full_clean(self, exclude=None):
-        u"""Валидация данных составной модели.
+        """Валидация данных составной модели.
 
         :param list exclude: Список полей составной модели, исключаемых из
             проверки. Например: 'relation', 'relation1.relation2.name'.
@@ -199,9 +208,7 @@ class ModelProxyValidationMixin(object):
         errors = {}
 
         models = (  # элементы составной модели
-            name
-            for name in (list(self.relations) + [primary_model_name])
-            if not exclude or name not in exclude
+            name for name in (list(self.relations) + [primary_model_name]) if not exclude or name not in exclude
         )
 
         for model_name in models:
@@ -233,8 +240,7 @@ class ModelProxyValidationMixin(object):
                 try:
                     model.full_clean(model_exclude)
                 except DjangoValidationError as error:
-                    errors = self.__update_error_dict(error, errors,
-                                                      model_name)
+                    errors = self.__update_error_dict(error, errors, model_name)
                     if not errors:
                         valid_key = '_ModelValidationMixin__object_is_valid'
                         model.__dict__[valid_key] = True
@@ -244,8 +250,7 @@ class ModelProxyValidationMixin(object):
 
 
 class BaseModelProxy(ModelProxyValidationMixin, ModelProxy):
-
-    u"""Базовый класс для составных прокси моделей с валидацией.
+    """Базовый класс для составных прокси моделей с валидацией.
 
     .. seealso::
         - :py:class: objectpack.models.ModelProxy
@@ -253,9 +258,8 @@ class BaseModelProxy(ModelProxyValidationMixin, ModelProxy):
     """
 
 
-class PackValidationMixin(object):
-
-    u"""Примесь к пакам из objectpack, добавляющая валидацию моделей.
+class PackValidationMixin:
+    """Примесь к пакам из objectpack, добавляющая валидацию моделей.
 
     Перед сохранением объекта в методе *save_row()* пака выполняется проверка
     данных путем вызова метода *full_clean()* сохраняемого объекта.
@@ -277,12 +281,13 @@ class PackValidationMixin(object):
 
     @convert_validation_error_to(ObjectPackValidationError)
     def save_row(self, obj, create_new, request, context):
-        u"""Вызывает проверку данных перед их сохранением в БД."""
-        from objectpack.slave_object_pack.actions import SlavePack
+        """Вызывает проверку данных перед их сохранением в БД."""
+        from objectpack.slave_object_pack.actions import (
+            SlavePack,
+        )
+
         if isinstance(self, SlavePack):
-            obj.__dict__.update(
-                self._get_parents_dict(context, key_fmt='%s_id')
-            )
+            obj.__dict__.update(self._get_parents_dict(context, key_fmt='%s_id'))
             save_row = super(SlavePack, self).save_row
         else:
             save_row = super(PackValidationMixin, self).save_row
@@ -298,7 +303,7 @@ class PackValidationMixin(object):
 
 
 def get_pack(pack_or_model):
-    u"""Возвращает экземпляр указанного пака.
+    """Возвращает экземпляр указанного пака.
 
     Пак может быть задан:
         - именем класса в пакете: 'extedu.unit.actions.Pack'
@@ -319,14 +324,8 @@ def get_pack(pack_or_model):
     """
     observer = ioc.get('observer')
 
-    if (
-        (
-            isinstance(pack_or_model, str) and
-            '.' in pack_or_model
-        ) or (
-            inspect.isclass(pack_or_model) and
-            issubclass(pack_or_model, ActionPack)
-        )
+    if (isinstance(pack_or_model, str) and '.' in pack_or_model) or (
+        inspect.isclass(pack_or_model) and issubclass(pack_or_model, ActionPack)
     ):
         # Пак задан именем класса в пакете или классом
         result = ControllerCache.find_pack(pack_or_model)
@@ -346,7 +345,7 @@ def get_pack(pack_or_model):
 
 
 def get_pack_id(pack_or_model):
-    u"""Возвращает имя параметра, идентифицирующего объект.
+    """Возвращает имя параметра, идентифицирующего объект.
 
     .. note::
        Вызов get_pack_id('Unit') аналогичен вызову
@@ -359,11 +358,12 @@ def get_pack_id(pack_or_model):
     """
     pack = get_pack(pack_or_model)
     result = pack.id_param_name
+
     return result
 
 
 def get_id_value(context, pack_or_model):
-    u"""Возвращает значение параметра, идентифицирующего объект.
+    """Возвращает значение параметра, идентифицирующего объект.
 
     Значение извлекается из контекста запроса *context*, имя параметра
     определяется свойством *id_param_name* пака. Пак определяется аргументом
@@ -379,13 +379,12 @@ def get_id_value(context, pack_or_model):
     :param pack_or_model: Аргумент, определяющий пак, из которого будет
         получено имя параметра, идентифицирующего объект (*id_param_name*).
     """
-    assert isinstance(
-        context, ObservableController.VerboseDeclarativeContext
-    ), type(context)
+    assert isinstance(context, ObservableController.VerboseDeclarativeContext), type(context)
 
     if isinstance(pack_or_model, (Action, ActionPack)):
         pack_or_model = pack_or_model.__class__
 
     pack = get_pack(pack_or_model)
     result = getattr(context, pack.id_param_name)
+
     return result
