@@ -1,22 +1,21 @@
-# coding: utf-8
-u"""Шаблон для построения отчётной системы.
+"""Шаблон для построения отчётной системы.
 
 Представляет собой набор абстрактных базовых и вспомогательных классов для
 различных элементов отчётной подсистемы: провайдера данных, построителя отчёта
 и собственно отчёта.
 """
-from __future__ import absolute_import
 
-from abc import ABCMeta
-from abc import abstractmethod
-from collections import Mapping
-
-import six
+from abc import (
+    ABCMeta,
+    abstractmethod,
+)
+from collections import (
+    Mapping,
+)
 
 
-class AbstractDataProvider(six.with_metaclass(ABCMeta, object)):
-
-    u"""Абстрактный класс провайдера данных.
+class AbstractDataProvider(metaclass=ABCMeta):
+    """Абстрактный класс провайдера данных.
 
     Данный класс является базовым для всех классов, реализующих функционал
     провайдера данных. Идеология провайдера данных следующая:
@@ -40,13 +39,13 @@ class AbstractDataProvider(six.with_metaclass(ABCMeta, object)):
     provider_name = None
 
     def init(self, **params):
-        u"""Инициализация провайдера.
+        """Инициализация провайдера.
 
         Используется вместо конструктора.
         """
 
     def load_data(self):
-        u"""Загрузка данных.
+        """Загрузка данных.
 
         Данный метод может быть описан и использоваться для подготовки
         данных или реализации каких-либо необходимых общих расчётов.
@@ -55,7 +54,7 @@ class AbstractDataProvider(six.with_metaclass(ABCMeta, object)):
 
     @property
     def name(self):
-        u"""Имя провайдера для применения в композитном провайдере."""
+        """Имя провайдера для применения в композитном провайдере."""
         if self.provider_name is not None:
             return self.provider_name
         else:
@@ -63,14 +62,13 @@ class AbstractDataProvider(six.with_metaclass(ABCMeta, object)):
 
 
 class CompositeDataProvider(AbstractDataProvider):
-
-    u"""Композитный провайдер данных.
+    """Композитный провайдер данных.
 
     Используется для объединения нескольких провайдеров в один.
     """
 
     def __init__(self, provider_classes):
-        u"""Конструктор композитного провайдера.
+        """Конструктор композитного провайдера.
 
         Здесь инстанцируются все подпровайдеры.
 
@@ -89,28 +87,27 @@ class CompositeDataProvider(AbstractDataProvider):
                 self.providers[_provider.name] = _provider
 
     def init(self, **params):
-        u"""Здесь инициализируются все подпровайдеры."""
-        for provider in six.itervalues(self.providers):
+        """Здесь инициализируются все подпровайдеры."""
+        for provider in self.providers.values():
             if hasattr(provider, 'init'):
                 provider.init(**params)
 
     def load_data(self):
-        u"""Загрузка данных во всех подпровайдерах."""
-        for provider in six.itervalues(self.providers):
+        """Загрузка данных во всех подпровайдерах."""
+        for provider in self.providers.values():
             if hasattr(provider, 'load_data'):
                 provider.load_data()
 
 
 class DependentCompositeProvider(AbstractDataProvider):
-
-    u"""
+    """
     Композитный провайдер с описанием подпровайдеров, порядка их загрузки.
 
     'Прокидывает' данные между подпровайдерами в процессе загрузки данных
     """
 
     providers_order = None
-    u"""
+    """
     Описание провайдеров в порядке их загрузки.
     Следует использовать "_" перед коротким именем провайдера,
     чтобы эти аттрибуты не уходили в адаптер
@@ -124,7 +121,7 @@ class DependentCompositeProvider(AbstractDataProvider):
         )
     """
     _dependence_map = None
-    u"""
+    """
     Описание карты дополнительных данных (между подпровайдерами).
     См. метод _extend_provider_data
 
@@ -157,7 +154,7 @@ class DependentCompositeProvider(AbstractDataProvider):
             self.providers[provider.name] = provider
 
     def _set_provider_to_loader(self, provider, shortname):
-        u"""
+        """
         Установка зависимого подпровайдера в список для загрузки.
 
         :param provider: провайдер данных, наследник AbstractDataProvider
@@ -168,20 +165,20 @@ class DependentCompositeProvider(AbstractDataProvider):
         setattr(self, shortname, provider)
 
     def init(self, **params):
-        u"""Инициализация подпровайдеров."""
+        """Инициализация подпровайдеров."""
         for provider in self._providers:
             if hasattr(provider, 'init'):
                 provider.init(**params)
 
     def load_data(self):
-        u"""Загрузка данных во всех подпровайдерах."""
+        """Загрузка данных во всех подпровайдерах."""
         for provider in self._providers:
             if hasattr(provider, 'load_data'):
                 self._extend_provider_data(provider)
                 provider.load_data()
 
     def _extend_provider_data(self, provider):
-        u"""
+        """
         Дополнение данных провайдера данными предыдущих загруженных провайдеров
         согласно карте зависимостей self._dependence_map
 
@@ -190,14 +187,13 @@ class DependentCompositeProvider(AbstractDataProvider):
         """
         # дополнение параметров результатами предыдущих провайдеров
         additional = self._dependence_map.get(provider._shortname, {})
-        for param, (dependent_provider_name, att) in six.iteritems(additional):
+        for param, (dependent_provider_name, att) in additional.items():
             dependent_provider = getattr(self, dependent_provider_name)
             setattr(provider, param, getattr(dependent_provider, att))
 
 
-class AbstractReportBuilder(six.with_metaclass(ABCMeta, object)):
-
-    u"""Абстрактный класс построителя отчётов.
+class AbstractReportBuilder(metaclass=ABCMeta):
+    """Абстрактный класс построителя отчётов.
 
     Имеет обязательный атрибут build(), вызов которого производит
     непосредственную генерацию отчёта.
@@ -206,7 +202,7 @@ class AbstractReportBuilder(six.with_metaclass(ABCMeta, object)):
     """
 
     def __init__(self, provider=None, adapter=None, *args, **kwargs):
-        u"""Конструктор класса билдера.
+        """Конструктор класса билдера.
 
         :param provider: Провайдер данных.
         :param adapter: Адаптер для извлечения данных из провайдера.
@@ -214,15 +210,14 @@ class AbstractReportBuilder(six.with_metaclass(ABCMeta, object)):
 
     @abstractmethod
     def build(self):
-        u""" Метод, осуществляющий построение отчёта.
+        """Метод, осуществляющий построение отчёта.
 
         Должен возвращать результат в виде файла или иной структуры данных.
         """
 
 
 class BaseProviderAdapter(Mapping, dict):
-
-    u"""Базовый класс для адаптеров, извлекающих данные из провайдера."""
+    """Базовый класс для адаптеров, извлекающих данные из провайдера."""
 
     # список атрибутов провайдера, которые не должны быть "видны" через адаптер
     _attrs_stop_list = (
@@ -234,7 +229,7 @@ class BaseProviderAdapter(Mapping, dict):
     )
 
     def __init__(self, provider):
-        u"""Конструктор адаптера.
+        """Конструктор адаптера.
 
         :param provider: провайдер данных
         """
@@ -243,16 +238,15 @@ class BaseProviderAdapter(Mapping, dict):
         self._cache = {}
 
     def _check_provider_attr(self, attr):
-        u"""Проверка атрибута - можно ли его брать из провайдера.
+        """Проверка атрибута - можно ли его брать из провайдера.
 
         'Магические' и некоторые отдельные методы будут игнорироваться.
         """
-        return not(attr.startswith('_') or attr in self._attrs_stop_list)
+        return not (attr.startswith('_') or attr in self._attrs_stop_list)
 
 
 class FlatDataProviderAdapter(BaseProviderAdapter):
-
-    u"""Данные провайдера в 'плоском' виде.
+    """Данные провайдера в 'плоском' виде.
 
     Класс адаптера, получающего все данные из провайдера и представляющего их
     в "плоском" виде (словарь с единичной глубиной):
@@ -265,23 +259,23 @@ class FlatDataProviderAdapter(BaseProviderAdapter):
     """
 
     def __init__(self, provider, splitter):
-        u"""Конструктор адаптера.
+        """Конструктор адаптера.
 
         :param provider: провайдер данных
         :param splitter: строка-разделитель.
         """
-        assert isinstance(splitter, six.string_types), type(splitter)
+        assert isinstance(splitter, str), type(splitter)
 
-        super(FlatDataProviderAdapter, self).__init__(provider)
+        super().__init__(provider)
 
         self.level_splitter = splitter
         self._all_keys = self._get_all_keys(self.provider)
 
     def _get_all_keys(self, provider, key_level=None):
-        u"""все ключи в иерархии провайдеров."""
+        """Все ключи в иерархии провайдеров."""
         result = []
         if key_level is None:
-            key_level = ""
+            key_level = ''
         else:
             if key_level:
                 key_level += self.level_splitter + provider.name
@@ -308,8 +302,8 @@ class FlatDataProviderAdapter(BaseProviderAdapter):
         return result
 
     def __getitem__(self, item):
-        u"""Поиск элемента с ключом item в словаре данных адаптера."""
-        if not isinstance(item, six.string_types):
+        """Поиск элемента с ключом item в словаре данных адаптера."""
+        if not isinstance(item, str):
             raise KeyError(item)
         if item not in self._all_keys:
             raise KeyError(item)
@@ -335,11 +329,12 @@ class FlatDataProviderAdapter(BaseProviderAdapter):
         return value
 
     def __len__(self):
-        u"""Магический метод для поддержки операции len()."""
+        """Магический метод для поддержки операции len()."""
         return len(self._all_keys)
 
     def __bool__(self):
         return bool(self._all_keys)
+
     __nonzero__ = __bool__
 
     def __iter__(self):
@@ -347,8 +342,7 @@ class FlatDataProviderAdapter(BaseProviderAdapter):
 
 
 class NestedDataProviderAdapter(BaseProviderAdapter):
-
-    u"""Данные провайдера в 'иерархическом' (вложенные словари) виде.
+    """Данные провайдера в 'иерархическом' (вложенные словари) виде.
 
     Класс адаптера, получающего все данные провайдера и представляющего их
     в виде вложенных словарей:
@@ -365,15 +359,16 @@ class NestedDataProviderAdapter(BaseProviderAdapter):
     """
 
     def __init__(self, provider):
-        u"""Конструктор адаптера.
+        """Конструктор адаптера.
 
         :param provider: провайдер данных
         """
-        super(NestedDataProviderAdapter, self).__init__(provider)
+        super().__init__(provider)
+
         self._all_keys = self._get_top_keys(self.provider)
 
     def _get_top_keys(self, provider):
-        u"""все необходимые атрибуты адаптируемого провайдера."""
+        """все необходимые атрибуты адаптируемого провайдера."""
         result = []
         for attr_name in dir(provider):
             # цикл по всем атрибутам провайдера
@@ -389,8 +384,8 @@ class NestedDataProviderAdapter(BaseProviderAdapter):
         return result
 
     def __getitem__(self, item):
-        u"""Поиск элемента с ключом item в словаре данных адаптера."""
-        if not isinstance(item, six.string_types):
+        """Поиск элемента с ключом item в словаре данных адаптера."""
+        if not isinstance(item, str):
             raise KeyError(item)
         if not self._check_provider_attr(item):
             raise KeyError(item)
@@ -413,11 +408,12 @@ class NestedDataProviderAdapter(BaseProviderAdapter):
             raise KeyError(item)
 
     def __len__(self):
-        u"""Магический метод для поддержки операции len()."""
+        """Магический метод для поддержки операции len()."""
         return len(self._all_keys)
 
     def __bool__(self):
         return bool(self._all_keys)
+
     __nonzero__ = __bool__
 
     def __iter__(self):
