@@ -1,13 +1,17 @@
-# coding: utf-8
-from __future__ import absolute_import
-
-from django.apps import config
-from django.db.models import CharField
-from django.db.models import TextField
-from django.db.models.functions import Lower
+from django.apps import (
+    config,
+)
+from django.db.models import (
+    CharField,
+    TextField,
+)
+from django.db.models.functions import (
+    Lower,
+)
 
 
 class AppConfig(config.AppConfig):
+    """Конфигурация приложения конструктора отчётов."""
 
     name = __name__.rpartition('.')[0]
     label = 'report_constructor'
