@@ -1,24 +1,45 @@
-# coding: utf-8
 # pylint: disable=protected-access
-from __future__ import absolute_import
+from django.core.exceptions import (
+    ValidationError,
+)
+from django.db import (
+    models,
+)
+from django.db.models.fields import (
+    Field,
+)
+from django.db.models.fields.related import (
+    RelatedField,
+)
+from django.db.models.fields.reverse_related import (
+    ForeignObjectRel,
+    OneToOneRel,
+)
+from django.utils.encoding import (
+    force_str,
+)
 
-from django.core.exceptions import FieldDoesNotExist
-from django.core.exceptions import ValidationError
-from django.db import models
-from django.db.models.fields import Field
-from django.db.models.fields.related import RelatedField
-from django.db.models.fields.reverse_related import ForeignObjectRel
-from django.db.models.fields.reverse_related import OneToOneRel
-from django.utils.encoding import force_text
-from m3_django_compat import ModelOptions
-from m3_django_compat import get_related
+from m3_django_compat import (
+    ModelOptions,
+    get_related,
+)
+from m3_django_compat.exceptions import (
+    FieldDoesNotExist,
+)
 
-from educommon.django.db.utils import LazyModel
-from educommon.report.constructor.utils import get_data_type
-from educommon.utils.misc import cached_property
-
-from . import constants
-from .utils import get_field
+from educommon.django.db.utils import (
+    LazyModel,
+)
+from educommon.report.constructor import (
+    constants,
+)
+from educommon.report.constructor.utils import (
+    get_data_type,
+    get_field,
+)
+from educommon.utils.misc import (
+    cached_property,
+)
 
 
 def _get_accessor_name(field):
@@ -56,10 +77,11 @@ def field_ignored_by_model_params(model, accessor_name):
 
     params = model.report_constructor_params
     assert isinstance(params, dict), params
-    assert sum(
-        1 if param in params else 0
-        for param in ('skip', 'except', 'only')
-    ) <= 1, (u'Должен быть указан только один параметр.', model, params)
+    assert sum(1 if param in params else 0 for param in ('skip', 'except', 'only')) <= 1, (
+        'Должен быть указан только один параметр.',
+        model,
+        params,
+    )
 
     if 'extra' in params and accessor_name in params['extra']:
         return False
@@ -80,13 +102,15 @@ def field_ignored_by_model_params(model, accessor_name):
         for param in params['only']:
             if param.split('.')[:parts_count] == parts:
                 return False
+            if param.split('.')[0] in parts:
+                return False
         return True
 
     return False
 
 
 def skip_field(model, field, accessor_name):
-    u"""Возвращает True, если поле модели должно игнорироваться конструктором.
+    """Возвращает True, если поле модели должно игнорироваться конструктором.
 
     Игнорируются:
         - поля с типами ``AutoField`` и ``FileField``;
@@ -107,15 +131,14 @@ def skip_field(model, field, accessor_name):
     return field_ignored_by_model_params(model, accessor_name)
 
 
-class ColumnDescriptor(object):
-
-    u"""Дескриптор поля модели, входящего в состав столбца отчета.
+class ColumnDescriptor:
+    """Дескриптор поля модели, входящего в состав столбца отчета.
 
     Предназначен для извлечения из моделей необходимой информации.
     """
 
     def __init__(self, data_source, parent, field, level=0):
-        u"""Инициализация экземпляра класса.
+        """Инициализация экземпляра класса.
 
         :param data_source: Источник данных.
 
@@ -140,18 +163,15 @@ class ColumnDescriptor(object):
             self.parent.children.append(self)
 
     def __repr__(self, *args, **kwargs):
-        return '{}<{}>'.format(
-            self.__class__.__name__, self.full_accessor_name
-        )
+        return '{}<{}>'.format(self.__class__.__name__, self.full_accessor_name)
 
     @staticmethod
     def create(model, field_name, data_source, parent=None, level=0):
         model_params = getattr(model, 'report_constructor_params', {})
-        assert sum(
-            1 if param in model_params else 0
-            for param in ('skip', 'except', 'only')
-        ) <= 1, (
-            u'Может быть указан только один параметр.', model, model_params
+        assert sum(1 if param in model_params else 0 for param in ('skip', 'except', 'only')) <= 1, (
+            'Может быть указан только один параметр.',
+            model,
+            model_params,
         )
 
         attr_name, _, nested_attr = field_name.partition('.')
@@ -182,9 +202,7 @@ class ColumnDescriptor(object):
                 raise FieldDoesNotExist(field_name)
 
             try:
-                result = ColumnDescriptor.create(
-                    related_model, nested_attr, data_source, result, level + 1
-                )
+                result = ColumnDescriptor.create(related_model, nested_attr, data_source, result, level + 1)
             except FieldDoesNotExist as error:
                 raise FieldDoesNotExist('.'.join((attr_name, str(error))))
 
@@ -206,11 +224,12 @@ class ColumnDescriptor(object):
         descriptor = self
         accessor_name = fld_accessor_name
         while descriptor.parent:
-            accessor_name = '.'.join(
-                (descriptor.accessor_name, accessor_name)
-            )
+            accessor_name = '.'.join((descriptor.accessor_name, accessor_name))
             if skip_field(descriptor.parent.model, field, accessor_name):
                 return True
+            # проверка, что связанная модель поля, не связана с родительскими моделями полей
+            if getattr(field, 'related_model', None) and field.related_model in descriptor.parent.related_field_models:
+                return True
 
             descriptor = descriptor.parent
         # проверка модели источника данных
@@ -231,35 +250,50 @@ class ColumnDescriptor(object):
 
         return model
 
+    @cached_property
+    def related_field_models(self):
+        """Связанные модели полей."""
+        fields_models = set()
+        # Для первых в корне добавляем модели источника данных.
+        if self.parent is None:
+            data_source_columns = tuple(self.data_source.get_available_columns())
+            fields_models.update({column.model for column in data_source_columns if column.model})
+            fields_models.add(self.data_source.model)
+
+        # получаем поля текущего экземпляра
+        if self.model:
+            fields = self.model._meta.get_fields()
+            fields_models.update({field.related_model for field in fields if field.related_model})
+            # добавляем саму модель экземпляра, если она есть
+            fields_models.add(self.model)
+
+        return fields_models
+
     @property
     def accessor_name(self):
-        return force_text(_get_accessor_name(self.field))
+        return force_str(_get_accessor_name(self.field))
 
     @property
     def lookup(self):
-        return force_text(self.field.name)
+        return force_str(self.field.name)
 
     @property
     def full_accessor_name(self):
         if self.parent:
-            return '.'.join(
-                (self.parent.full_accessor_name, self.accessor_name)
-            )
+            return '.'.join((self.parent.full_accessor_name, self.accessor_name))
         else:
             return self.accessor_name
 
     @property
     def full_lookup(self):
         if self.parent:
-            return '__'.join(
-                (self.parent.full_lookup, self.lookup)
-            )
+            return '__'.join((self.parent.full_lookup, self.lookup))
         else:
             return self.lookup
 
     @property
     def data_type(self):
-        u"""Тип данных в столбце.
+        """Тип данных в столбце.
 
         :rtype: str
         """
@@ -272,15 +306,12 @@ class ColumnDescriptor(object):
 
     @property
     def choices(self):
-        u"""Допустимые значения столбца с описанием."""
+        """Допустимые значения столбца с описанием."""
         return self.field.choices or None
 
     @property
     def title(self):
-        if (
-            self.data_source.field_titles and
-            self.full_accessor_name in self.data_source.field_titles
-        ):
+        if self.data_source.field_titles and self.full_accessor_name in self.data_source.field_titles:
             return self.data_source.field_titles[self.full_accessor_name]
 
         if isinstance(self.field, ForeignObjectRel):
@@ -292,19 +323,17 @@ class ColumnDescriptor(object):
         else:
             result = self.field.verbose_name
 
-        return force_text(result)
+        return force_str(result)
 
-    def get_full_title(self, delimiter=u' → '):
-        u"""Возвращает полное наименование с учетом иерархии.
+    def get_full_title(self, delimiter=' → '):
+        """Возвращает полное наименование с учетом иерархии.
 
-        :param unicode delimiter: Разделитель наименований.
+        :param str delimiter: Разделитель наименований.
 
-        :rtype: unicode
+        :rtype: str
         """
         if self.parent:
-            return delimiter.join((
-                self.parent.get_full_title(delimiter), self.title
-            ))
+            return delimiter.join((self.parent.get_full_title(delimiter), self.title))
         else:
             return self.title
 
@@ -328,10 +357,7 @@ class ColumnDescriptor(object):
             if not self._check_to_exclude(field):
                 return True
 
-        if (
-            hasattr(self.model, 'report_constructor_params') and
-            'extra' in self.model.report_constructor_params
-        ):
+        if hasattr(self.model, 'report_constructor_params') and 'extra' in self.model.report_constructor_params:
             extra = self.model.report_constructor_params['extra']
             for accessor_name, params in extra.items():
                 field = ExtraField(accessor_name, params['field'])
@@ -346,38 +372,29 @@ class ColumnDescriptor(object):
         else:
             for field in getattr(self.model, '_meta').get_fields():
                 if not self._check_to_exclude(field):
-                    yield ColumnDescriptor(
-                        self.data_source, self, field, level=self.level + 1
-                    )
+                    yield ColumnDescriptor(self.data_source, self, field, level=self.level + 1)
 
-            if (
-                hasattr(self.model, 'report_constructor_params') and
-                'extra' in self.model.report_constructor_params
-            ):
+            if hasattr(self.model, 'report_constructor_params') and 'extra' in self.model.report_constructor_params:
                 extra = self.model.report_constructor_params['extra']
                 for accessor_name, params in extra.items():
                     field = ExtraField(accessor_name, params['field'])
                     if not self._check_to_exclude(field):
-                        yield ColumnDescriptor(
-                            self.data_source,
-                            self, field,
-                            level=self.level + 1
-                        )
+                        yield ColumnDescriptor(self.data_source, self, field, level=self.level + 1)
 
     def validate_value(self, value):
-        u"""Проверяет текстовое представление значения на соотв-е типу поля.
+        """Проверяет текстовое представление значения на соотв-е типу поля.
 
-        :param unicode value: Текстовое представление значения для проверки.
+        :param str value: Текстовое представление значения для проверки.
 
         :raises django.core.exceptions.ValidationError: если значение аргумента
             value не прошло проверку. Описание ошибки будет в исключении.
         """
         if self.data_type == constants.CT_REVERSE_RELATION:
-            raise ValidationError(u'Обратная связь не доступна для сравнения.')
+            raise ValidationError('Обратная связь не доступна для сравнения.')
         # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 
         elif self.data_type == constants.CT_DIRECT_RELATION:
-            raise ValidationError(u'Ключевые поля не доступны для сравнения.')
+            raise ValidationError('Ключевые поля не доступны для сравнения.')
         # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 
         elif self.data_type == constants.CT_CHOICES:
@@ -386,10 +403,7 @@ class ColumnDescriptor(object):
                 if choice_display.lower() == lower_case_value:
                     break
             else:
-                raise ValidationError(
-                    u'Недопустимое значение для сравнения: {}.'
-                    .format(value)
-                )
+                raise ValidationError('Недопустимое значение для сравнения: {}.'.format(value))
         # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 
         else:
@@ -399,9 +413,8 @@ class ColumnDescriptor(object):
         # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 
 
-class FakeField(object):
-
-    u"""Класс несуществующего поля модели для отчета.
+class FakeField:
+    """Класс несуществующего поля модели для отчета.
 
     Предназначен для подмены реальных полей при отображении в отчете.
     """
@@ -414,9 +427,8 @@ class FakeField(object):
         self.data_type = constants.CT_OTHER
 
 
-class ExtraField(object):
-
-    u"""Класс дополнительного поля модели.
+class ExtraField:
+    """Класс дополнительного поля модели.
 
     Используется для доступа к атрибутам объектов моделей, а также результатам
     вызова функций с объектом модели в качестве аргумента.
@@ -464,12 +476,11 @@ class ExtraField(object):
         return self._field.formfield
 
 
-class _ModelDataSourceInfo(object):
-
-    u"""Клас-примесь для работы с информацией об источнике данных."""
+class _ModelDataSourceInfo:
+    """Клас-примесь для работы с информацией об источнике данных."""
 
     def __init__(self, model, filter_func=None, field_titles=None):
-        u"""Инициализация экземпляра.
+        """Инициализация экземпляра.
 
         :param model: Модель, для источника данных которой определяются
             параметры. См. :class:`educommon.django.db.utils.LazyModel`
@@ -487,8 +498,8 @@ class _ModelDataSourceInfo(object):
                _ModelDataSourceInfo(
                    ...,
                    field_titles={
-                       'restored_to': u'Сведения до восстановления',
-                       'person.surname': u'Фамилия физ. лица',
+                       'restored_to': 'Сведения до восстановления',
+                       'person.surname': 'Фамилия физ. лица',
                    }
                )
         """
@@ -502,32 +513,28 @@ class _ModelDataSourceInfo(object):
 
     @cached_property
     def name(self):
-        u"""Внутрисистемное имя источника данных."""
+        """Внутрисистемное имя источника данных."""
         result = '.'.join((self._model.app_label, self._model.model_name))
 
-        return force_text(result)
+        return force_str(result)
 
     @cached_property
     def title(self):
-        u"""Отображаемое пользователю наименование источника данных."""
+        """Отображаемое пользователю наименование источника данных."""
         result = getattr(self.model, '_meta').verbose_name
-        return force_text(result)
+        return force_str(result)
 
 
 class ModelDataSourceParams(_ModelDataSourceInfo):
-
-    u"""Параметры для дескриптора источника данных в шаблоне отчета."""
+    """Параметры для дескриптора источника данных в шаблоне отчета."""
 
     def get_data_source_descriptor(self):
-        u"""Возвращает дескриптор источника данных."""
-        return ModelDataSourceDescriptor(
-            self._model.get_model(), self._filter_func, self.field_titles
-        )
+        """Возвращает дескриптор источника данных."""
+        return ModelDataSourceDescriptor(self._model.get_model(), self._filter_func, self.field_titles)
 
 
 class ModelDataSourceDescriptor(_ModelDataSourceInfo):
-
-    u"""Дескриптор модели, являющейся источником данных в шаблоне отчета."""
+    """Дескриптор модели, являющейся источником данных в шаблоне отчета."""
 
     def __init__(self, *args, **kwargs):
         super(ModelDataSourceDescriptor, self).__init__(*args, **kwargs)
@@ -539,7 +546,7 @@ class ModelDataSourceDescriptor(_ModelDataSourceInfo):
         return ModelOptions(self._model.get_model())
 
     def add_source_filter(self, query, include_available_units, user):
-        u"""Добавление фильтра к источнику данных."""
+        """Добавление фильтра к источнику данных."""
         if self._filter_func:
             return self._filter_func(query, include_available_units, user)
         return query
@@ -551,10 +558,7 @@ class ModelDataSourceDescriptor(_ModelDataSourceInfo):
             if not skip_field(model, field, _get_accessor_name(field)):
                 yield ColumnDescriptor(self, None, field)
 
-        if (
-            hasattr(model, 'report_constructor_params') and
-            'extra' in model.report_constructor_params
-        ):
+        if hasattr(model, 'report_constructor_params') and 'extra' in model.report_constructor_params:
             extra = model.report_constructor_params['extra']
             for accessor_name, params in extra.items():
                 field = ExtraField(accessor_name, params['field'])
@@ -562,7 +566,7 @@ class ModelDataSourceDescriptor(_ModelDataSourceInfo):
 
     @staticmethod
     def _get_model_field_by_name(model, field_name):
-        u"""Получает поле модели и модель связанную с ним по его имени.
+        """Получает поле модели и модель связанную с ним по его имени.
 
         Рейзит FieldDoesNotExist если поле с таким именем не найдено.
         """
@@ -587,20 +591,18 @@ class ModelDataSourceDescriptor(_ModelDataSourceInfo):
 
         else:
             if (
-                hasattr(model, 'report_constructor_params') and
-                'extra' in model.report_constructor_params and
-                field_name in model.report_constructor_params['extra']
+                hasattr(model, 'report_constructor_params')
+                and 'extra' in model.report_constructor_params
+                and field_name in model.report_constructor_params['extra']
             ):
                 column_field = get_field(model, field_name)
             else:
-                raise FieldDoesNotExist(
-                    '{}.{}'.format(model.__name__, field_name)
-                )
+                raise FieldDoesNotExist('{}.{}'.format(model.__name__, field_name))
 
         return column_field, model
 
     def is_column_ignored(self, accessor_name):
-        u"""Проверяет исключение модели ``model.report_constructor_params``.
+        """Проверяет исключение модели ``model.report_constructor_params``.
 
         :param str accessor_name: путь, через ".", до поля от указанной модели.
 
@@ -618,7 +620,7 @@ class ModelDataSourceDescriptor(_ModelDataSourceInfo):
         return False
 
     def is_column_exist(self, accessor_name):
-        u"""Проверяет существование поля в моделе.
+        """Проверяет существование поля в моделе.
 
         :param str accessor_name: путь, через ".", до поля от указанной модели.
 
@@ -634,7 +636,7 @@ class ModelDataSourceDescriptor(_ModelDataSourceInfo):
         return True
 
     def get_column_descriptor(self, accessor_name):
-        u"""Возвращает дескриптор столбца по его имени.
+        """Возвращает дескриптор столбца по его имени.
 
         .. code-block:: python
 
@@ -654,25 +656,21 @@ class ModelDataSourceDescriptor(_ModelDataSourceInfo):
             # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
             # Поиск поля в модели.
 
-            column_field, model = self._get_model_field_by_name(
-                model, level_name
-            )
+            column_field, model = self._get_model_field_by_name(model, level_name)
             # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
             # Создание дескриптора столбца, если его нет в кэше.
 
             if full_accessor_name in self.column_descriptors_cache:
                 result = self.column_descriptors_cache[full_accessor_name]
             else:
-                result = ColumnDescriptor(
-                    self, result, column_field, len(level_names) - 1
-                )
+                result = ColumnDescriptor(self, result, column_field, len(level_names) - 1)
                 self.column_descriptors_cache[full_accessor_name] = result
             # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 
         return result
 
     def get_fake_column_descriptor(self, column_name):
-        u"""Возвращает дескриптор отсутствующего столбца по его имени.
+        """Возвращает дескриптор отсутствующего столбца по его имени.
 
         .. code-block:: python
 
@@ -691,17 +689,13 @@ class ModelDataSourceDescriptor(_ModelDataSourceInfo):
                 result = self.column_descriptors_cache[full_accessor_name]
 
             if not model:
-                return ColumnDescriptor(
-                    self, result, FakeField(column_name), len(level_names) - 1
-                )
+                return ColumnDescriptor(self, result, FakeField(column_name), len(level_names) - 1)
             # Создание дескриптора столбца, если его нет в кэше.
 
             if full_accessor_name in self.column_descriptors_cache:
                 result = self.column_descriptors_cache[full_accessor_name]
             else:
-                result = ColumnDescriptor(
-                    self, result, FakeField(column_name), len(level_names) - 1
-                )
+                result = ColumnDescriptor(self, result, FakeField(column_name), len(level_names) - 1)
                 self.column_descriptors_cache[full_accessor_name] = result
             # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 
