@@ -1,49 +1,82 @@
-# coding: utf-8
-from __future__ import absolute_import
+from collections import (
+    OrderedDict,
+    defaultdict,
+)
+from itertools import (
+    chain,
+    repeat,
+)
 
-from collections import OrderedDict
-from collections import defaultdict
-from itertools import chain
-from itertools import repeat
+from django.contrib.contenttypes.models import (
+    ContentType,
+)
+from django.db.transaction import (
+    atomic,
+)
+from m3.actions.exceptions import (
+    ApplicationLogicException,
+)
+from m3.actions.results import (
+    OperationResult,
+    PreJsonResult,
+)
+from m3_ext.ui.results import (
+    ExtUIScriptResult,
+)
 
-from django.contrib.contenttypes.models import ContentType
-from django.core.exceptions import FieldDoesNotExist
-from django.db.transaction import atomic
-from m3.actions.exceptions import ApplicationLogicException
-from m3.actions.results import OperationResult
-from m3.actions.results import PreJsonResult
-from m3_ext.ui.results import ExtUIScriptResult
-from objectpack.actions import BaseAction
-from objectpack.actions import ObjectPack
-from objectpack.exceptions import ValidationError
-from objectpack.ui import BaseEditWindow
-from objectpack.ui import make_combo_box
-from six.moves import map
-from six.moves import zip
-import six
+from m3_django_compat.exceptions import (
+    FieldDoesNotExist,
+)
+from objectpack.actions import (
+    BaseAction,
+    ObjectPack,
+)
+from objectpack.exceptions import (
+    ValidationError,
+)
+from objectpack.ui import (
+    BaseEditWindow,
+    make_combo_box,
+)
 
-from educommon.m3 import PackValidationMixin
-from educommon.m3 import convert_validation_error_to
-from educommon.m3 import get_id_value
-from educommon.report.constructor.config import report_constructor_config
-from educommon.utils.misc import cached_property
-from educommon.utils.ui import anchor100
-
-from .. import constants
-from ..base import ColumnDescriptor
-from ..models import ReportColumn
-from ..models import ReportFilter
-from ..models import ReportFilterGroup
-from ..models import ReportSorting
-from ..models import ReportTemplate
-from ..registries import registry
-from .ui import EditWindow
-from .ui import ListWindow
+from educommon.m3 import (
+    PackValidationMixin,
+    convert_validation_error_to,
+    get_id_value,
+)
+from educommon.report.constructor import (
+    constants,
+)
+from educommon.report.constructor.base import (
+    ColumnDescriptor,
+)
+from educommon.report.constructor.config import (
+    report_constructor_config,
+)
+from educommon.report.constructor.editor.ui import (
+    EditWindow,
+    ListWindow,
+)
+from educommon.report.constructor.models import (
+    ReportColumn,
+    ReportFilter,
+    ReportFilterGroup,
+    ReportSorting,
+    ReportTemplate,
+)
+from educommon.report.constructor.registries import (
+    registry,
+)
+from educommon.utils.misc import (
+    cached_property,
+)
+from educommon.utils.ui import (
+    anchor100,
+)
 
 
 class ColumnsAction(BaseAction):
-
-    u"""Действие, предоставляющее данные для дерева столбцов."""
+    """Действие, предоставляющее данные для дерева столбцов."""
 
     def context_declaration(self):
         return dict(
@@ -68,42 +101,31 @@ class ColumnsAction(BaseAction):
 
     def run(self, request, context):
         if context.data_source_name not in registry:
-            raise ApplicationLogicException(u'Не выбран источник данных.')
+            raise ApplicationLogicException('Не выбран источник данных.')
 
-        if context.parent_column_name == u'-1':
+        if context.parent_column_name == '-1':
             context.parent_column_name = None
 
-        data_source = registry.get(
-            context.data_source_name
-        ).get_data_source_descriptor()
+        data_source = registry.get(context.data_source_name).get_data_source_descriptor()
 
         if context.parent_column_name:
-            parent_column = ColumnDescriptor.create(
-                data_source.model, context.parent_column_name, data_source
-            )
+            parent_column = ColumnDescriptor.create(data_source.model, context.parent_column_name, data_source)
             columns = parent_column.get_nested_columns()
         else:
-            columns = tuple(
-                data_source.get_available_columns()
-            )
+            columns = tuple(data_source.get_available_columns())
 
-        return PreJsonResult(tuple(
-            map(ColumnsAction._get_column_params, columns)
-        ))
+        return PreJsonResult(tuple(map(ColumnsAction._get_column_params, columns)))
 
 
 _BUILDERS_PACKAGE = 'educommon.report.constructor.builders'
 
 
 class BuildAction(BaseAction):
-
-    u"""Сборка отчета на основе указанного шаблона."""
+    """Сборка отчета на основе указанного шаблона."""
 
     _builders = {
-        ReportTemplate.EXCEL_SIMPLE:
-            _BUILDERS_PACKAGE + '.excel.product.ReportBuilder',
-        ReportTemplate.EXCEL_MERGED:
-            _BUILDERS_PACKAGE + '.excel.with_merged_cells.ReportBuilder',
+        ReportTemplate.EXCEL_SIMPLE: f'{_BUILDERS_PACKAGE}.excel.product.ReportBuilder',
+        ReportTemplate.EXCEL_MERGED: f'{_BUILDERS_PACKAGE}.excel.with_merged_cells.ReportBuilder',
     }
 
     def context_declaration(self):
@@ -115,9 +137,7 @@ class BuildAction(BaseAction):
     def _get_report_template(self, request, context):
         # Загрузка шаблона
         try:
-            return ReportTemplate.objects.get(
-                pk=get_id_value(context, self.parent)
-            )
+            return ReportTemplate.objects.get(pk=get_id_value(context, self.parent))
         except ReportTemplate.DoesNotExist:
             raise ApplicationLogicException(self.parent.MSG_DOESNOTEXISTS)
 
@@ -126,41 +146,29 @@ class BuildAction(BaseAction):
         # шаблоне.
         if report_template.data_source_name not in registry:
             raise ApplicationLogicException(
-                u'Источник данных {} не существует.'
-                .format(report_template.data_source_name)
+                'Источник данных {} не существует.'.format(report_template.data_source_name)
             )
 
-        data_source = registry.get(
-            report_template.data_source_name
-        ).get_data_source_descriptor()
+        data_source = registry.get(report_template.data_source_name).get_data_source_descriptor()
 
         if ReportInfo(report_template).ignored_columns_ids:
-            raise ApplicationLogicException(
-                u'Некоторые колонки шаблона неактуальны, '
-                u'требуется редактирование'
-            )
+            raise ApplicationLogicException('Некоторые колонки шаблона неактуальны, требуется редактирование')
 
         # Проверка доступности данных для всех столбцов шаблона отчета.
         try:
-            for col_name in report_template.columns.values_list(
-                    'name', flat=True):
+            for col_name in report_template.columns.values_list('name', flat=True):
                 if data_source.is_column_ignored(col_name):
                     continue
                 data_source.get_column_descriptor(col_name)
         except FieldDoesNotExist as error:
-            raise ApplicationLogicException(
-                u'Колонка {} недоступна'.format(six.text_type(error))
-            )
+            raise ApplicationLogicException('Колонка {} недоступна'.format(str(error)))
 
     def _check_params(self, request, context, report_template):
-        u"""Возвращает True, если параметры сборки указаны верно."""
+        """Возвращает True, если параметры сборки указаны верно."""
         if context.format is None:
             return report_template.format in self._builders
 
-        if (
-            report_template.format == ReportTemplate.USER_DEFINED and
-            context.format in self._builders
-        ):
+        if report_template.format == ReportTemplate.USER_DEFINED and context.format in self._builders:
             return True
 
         return False
@@ -169,26 +177,30 @@ class BuildAction(BaseAction):
         win = BaseEditWindow()
 
         win.field__format = make_combo_box(
-            label=u'Формат отчета',
+            label='Формат отчета',
             name='format',
             data=ReportTemplate.FORMAT_CHOICES[1:],
         )
 
-        win.form.items.extend(anchor100(
-            win.field__format,
-        ))
+        win.form.items.extend(
+            anchor100(
+                win.field__format,
+            )
+        )
 
-        win.set_params(dict(
-            form_url=self.get_absolute_url(),
-            height=100,
-            title=u'Параметры сборки',
-        ))
+        win.set_params(
+            dict(
+                form_url=self.get_absolute_url(),
+                height=100,
+                title='Параметры сборки',
+            )
+        )
 
         return ExtUIScriptResult(win, context)
 
     def _check_format(self, report_format):
         if report_format not in self._builders:
-            raise ApplicationLogicException(u'Указан неверный формат отчета.')
+            raise ApplicationLogicException('Указан неверный формат отчета.')
 
     def _build_report(self, request, context):
         report_template_id = get_id_value(context, self.parent)
@@ -199,13 +211,12 @@ class BuildAction(BaseAction):
             'object_id': user.id,
             'content_type': content_type,
             'report_template_id': report_template_id,
-            'format': context.format or None
+            'format': context.format or None,
         }
         report_constructor_config.async_task.apply_async(None, params)
 
         return OperationResult(
-            message=u'Внимание! Задача поставлена в очередь! Результаты '
-                    u'будут доступны в реестре Асинхронных задач.'
+            message='Внимание! Задача поставлена в очередь! Результаты будут доступны в реестре Асинхронных задач.'
         )
 
     def run(self, request, context):
@@ -220,78 +231,65 @@ class BuildAction(BaseAction):
             return self._get_params_window(request, context, report_template)
 
 
-class ReportInfo(object):
-
-    u"""Сведения о столбцах отчета, подготовленные к сериализации в JSON."""
+class ReportInfo:
+    """Сведения о столбцах отчета, подготовленные к сериализации в JSON."""
 
     def __init__(self, report_template):
-        u"""Инициализация экземпляра класса.
+        """Инициализация экземпляра класса.
 
         :param report_template: Шаблон отчета.
         :type report_template:
             educommon.report.constructor.models.ReportTemplate
         """
-        assert isinstance(report_template, ReportTemplate), type(
-            report_template
-        )
+        assert isinstance(report_template, ReportTemplate), type(report_template)
 
         self.report_template = report_template
 
     @cached_property
     def _data_source(self):
-        u"""Источник данных шаблона.
+        """Источник данных шаблона.
 
         :rtype: educommon.report.constructor.base.ModelDataSourceDescriptor
         """
-        data_source = registry.get(
-            self.report_template.data_source_name
-        ).get_data_source_descriptor()
+        data_source = registry.get(self.report_template.data_source_name).get_data_source_descriptor()
         return data_source
 
     @cached_property
     def ignored_columns_ids(self):
-        u"""Список колонок исключенных из конструктора отчетов.
+        """Список колонок исключенных из конструктора отчетов.
 
         Исключается параметром ``model.report_constructor_params``.
 
         :rtype: set
         """
         ignored_columns = set()
-        for col_id, col_name in self.report_template.columns.values_list(
-                'id', 'name'):
-            if (self._data_source.is_column_ignored(col_name) or
-                    not self._data_source.is_column_exist(col_name)):
+        for col_id, col_name in self.report_template.columns.values_list('id', 'name'):
+            if self._data_source.is_column_ignored(col_name) or not self._data_source.is_column_exist(col_name):
                 ignored_columns.add(col_id)
 
         return ignored_columns
 
     @cached_property
     def _report_columns_by_id(self):
-        u"""Колонки отчета по id.
+        """Колонки отчета по id.
 
         :rtype: collections.OrderedDict
         """
         columns = self.report_template.columns.order_by('index')
 
-        return OrderedDict(
-            (report_column.id, report_column)
-            for report_column in columns
-        )
+        return OrderedDict((report_column.id, report_column) for report_column in columns)
 
     @cached_property
     def _report_columns_by_name(self):
-        u"""Колонки отчета по имени.
+        """Колонки отчета по имени.
 
         :rtype: collections.OrderedDict
         """
-        return OrderedDict(
-            (report_column.name, report_column)
-            for report_column in six.itervalues(self._report_columns_by_id)
-        )
+        return OrderedDict((report_column.name, report_column) for report_column in self._report_columns_by_id.values())
 
     @cached_property
     def _field_descriptors(self):
-        u"""Дескрипторы полей в источнике данных.
+        """Дескрипторы полей в источнике данных.
 
         :rtype: collections.OrderedDict
         """
@@ -300,7 +298,7 @@ class ReportInfo(object):
 
         descriptors = OrderedDict()
 
-        for report_column in six.itervalues(self._report_columns_by_name):
+        for report_column in self._report_columns_by_name.values():
             if report_column.id in self.ignored_columns_ids:
                 descriptor = get_fake_descriptor(report_column.title)
             else:
@@ -314,17 +312,15 @@ class ReportInfo(object):
 
     @cached_property
     def _fields_hierarchy(self):
-        u"""Иерархия полей в источнике данных.
+        """Иерархия полей в источнике данных.
 
         :rtype: collections.defaultdict
         """
         hierarchy = defaultdict(list)
 
-        for descriptor in six.itervalues(self._field_descriptors):
+        for descriptor in self._field_descriptors.values():
             if not descriptor.is_root():
-                hierarchy[descriptor.parent.full_accessor_name].append(
-                    descriptor
-                )
+                hierarchy[descriptor.parent.full_accessor_name].append(descriptor)
 
         return hierarchy
 
@@ -339,21 +335,14 @@ class ReportInfo(object):
             full_name=full_accessor_name,
             title=descriptor.title,
             leaf=not descriptor.has_nested_columns(),
-            nested=tuple(
-                self._get_descriptor_data(descriptor)
-                for descriptor in nested_descriptors
-            ),
+            nested=tuple(self._get_descriptor_data(descriptor) for descriptor in nested_descriptors),
         )
         column = self._report_columns_by_name.get(full_accessor_name, None)
         column_id = getattr(column, 'id', 0)
-        result['is_fake'] = (
-            not column_id or column_id in self.ignored_columns_ids
-        )
+        result['is_fake'] = not column_id or column_id in self.ignored_columns_ids
         if full_accessor_name in self._report_columns_by_name:
-            result['visible'] = (
-                self._report_columns_by_name[full_accessor_name].visible
-            )
-            result['visible_title'] = u'Да' if result['visible'] else u'Нет'
+            result['visible'] = self._report_columns_by_name[full_accessor_name].visible
+            result['visible_title'] = 'Да' if result['visible'] else 'Нет'
 
             # "Количество"
             result['by_value'] = column.by_value
@@ -378,10 +367,10 @@ class ReportInfo(object):
         return result
 
     def get_columns_data(self):
-        u"""Возвращает параметры столбцов шаблона."""
+        """Возвращает параметры столбцов шаблона."""
         return tuple(
             self._get_descriptor_data(descriptor)
-            for descriptor in six.itervalues(self._field_descriptors)
+            for descriptor in self._field_descriptors.values()
             if descriptor.is_root()
         )
 
@@ -392,64 +381,53 @@ class ReportInfo(object):
 
     @cached_property
     def _filter_groups(self):
-        u"""Группы фильтров.
+        """Группы фильтров.
 
         :rtype: collections.OrderedDict
         """
         tree_manager = getattr(ReportFilterGroup, '_tree_manager')
         filter_groups_query = tree_manager.get_queryset_descendants(
-            self.report_template.filter_groups.exclude(
-                filters__column_id__in=self.ignored_columns_ids
-            ),
-            include_self=True
+            self.report_template.filter_groups.exclude(filters__column_id__in=self.ignored_columns_ids),
+            include_self=True,
         ).prefetch_related('filters')
 
-        return OrderedDict(
-            (filter_group.pk, filter_group)
-            for filter_group in filter_groups_query
-        )
+        return OrderedDict((filter_group.pk, filter_group) for filter_group in filter_groups_query)
 
     def _get_filter_data(self, report_filter):
-        u"""Возвращает параметры фильтра.
+        """Возвращает параметры фильтра.
 
         :rtype: dict
         """
         column = self._report_columns_by_id[report_filter.column_id]
 
         return dict(
-           column=column.name,
-           index=report_filter.index,
-           operator=report_filter.operator,
-           exclude=report_filter.exclude,
-           case_sensitive=report_filter.case_sensitive,
-           values=report_filter.values or [],
-           comment=report_filter.comment,
+            column=column.name,
+            index=report_filter.index,
+            operator=report_filter.operator,
+            exclude=report_filter.exclude,
+            case_sensitive=report_filter.case_sensitive,
+            values=report_filter.values or [],
+            comment=report_filter.comment,
         )
 
     def _get_filter_group_data(self, filter_group):
-        u"""Возвращает парамеры группы фильтров.
+        """Возвращает парамеры группы фильтров.
 
         :rtype: dict
         """
         nested_groups = (
-            nested_group
-            for nested_group in six.itervalues(self._filter_groups)
-            if nested_group.parent_id == filter_group.pk
+            nested_group for nested_group in self._filter_groups.values() if nested_group.parent_id == filter_group.pk
         )
 
         return {
             self._OPERATOR_MAP[filter_group.operator]: tuple(
-                (
-                    self._get_filter_group_data(obj)
-                    if isinstance(obj, ReportFilterGroup) else
-                    self._get_filter_data(obj)
-                )
+                (self._get_filter_group_data(obj) if isinstance(obj, ReportFilterGroup) else self._get_filter_data(obj))
                 for obj in chain(nested_groups, filter_group.filters.all())
             )
         }
 
     def get_filters_data(self):
-        u"""Возвращает параметры фильтров.
+        """Возвращает параметры фильтров.
 
         Т.к. в БД фильтры хранятся в виде дерева (синтаксическое дерево), а в
         окне редактирования фильтры организованы в виде плоского списка (так
@@ -471,13 +449,13 @@ class ReportInfo(object):
                                {
                                    'column': 'group.unit.short_name',
                                    'operator': 3,
-                                   'value': u'СДЮШОР1',
+                                   'value': 'СДЮШОР1',
                                    ...
                                },
                                {
                                    'column': 'group.unit.short_name',
                                    'operator': 3,
-                                   'value': u'СДЮШОР2',
+                                   'value': 'СДЮШОР2',
                                    ...
                                },
                            ),
@@ -504,22 +482,20 @@ class ReportInfo(object):
         """
         return tuple(
             self._get_filter_group_data(filter_group)
-            for filter_group in six.itervalues(self._filter_groups)
+            for filter_group in self._filter_groups.values()
             if filter_group.parent_id is None
         )
 
     @cached_property
     def _sorting_params_by_column_name(self):
-        u"""Параметры сортировки.
+        """Параметры сортировки.
 
         :rtype: tuple
         """
         result = tuple(
-            ReportSorting.objects.filter(
-                column__report_template=self.report_template
-            ).exclude(
-                column_id__in=self.ignored_columns_ids
-            ).order_by('index')
+            ReportSorting.objects.filter(column__report_template=self.report_template)
+            .exclude(column_id__in=self.ignored_columns_ids)
+            .order_by('index')
         )
 
         for sorting_params in result:
@@ -529,7 +505,7 @@ class ReportInfo(object):
         return result
 
     def _get_sorting_data(self, report_sorting):
-        u"""Возвращает парамеры сортировки в пригодном для сериализации виде.
+        """Возвращает парамеры сортировки в пригодном для сериализации виде.
 
         :rtype: dict
         """
@@ -539,20 +515,15 @@ class ReportInfo(object):
         )
 
     def get_sorting_data(self):
-        u"""Возвращает параметры сортировки."""
-        return tuple(
-            self._get_sorting_data(sorting_params)
-            for sorting_params in self._sorting_params_by_column_name
-        )
+        """Возвращает параметры сортировки."""
+        return tuple(self._get_sorting_data(sorting_params) for sorting_params in self._sorting_params_by_column_name)
 
 
-class ReportTemplateWriter(object):
+class ReportTemplateWriter:
+    """Класс, сохраняющий в БД данные шаблона отчета."""
 
-    u"""Класс, сохраняющий в БД данные шаблона отчета."""
-
-    def __init__(self, report_template, columns_data, filters_data,
-                 sorting_data):
-        u"""Инициализация экземпляра класса.
+    def __init__(self, report_template, columns_data, filters_data, sorting_data):
+        """Инициализация экземпляра класса.
 
         :param report_template: Шаблон отчета
         :type report_template:
@@ -580,7 +551,7 @@ class ReportTemplateWriter(object):
         self._report_columns = {}
 
     def _is_report_template_valid(self, report_template):
-        u"""Возвращает True, если шаблон отчета корректный.
+        """Возвращает True, если шаблон отчета корректный.
 
         Перечень проверок:
 
@@ -589,15 +560,12 @@ class ReportTemplateWriter(object):
         :rtype: bool
         """
         if report_template.data_source_name not in registry:
-            self.errors.append(
-                u'Источник данных "{}" не существует.'
-                .format(report_template.data_source_name)
-            )
+            self.errors.append('Источник данных "{}" не существует.'.format(report_template.data_source_name))
 
         return not self.errors
 
     def _is_columns_data_valid(self, columns_data):
-        u"""Возвращает True, если параметры столбцов корректны.
+        """Возвращает True, если параметры столбцов корректны.
 
         Перечень проверок:
 
@@ -609,54 +577,41 @@ class ReportTemplateWriter(object):
         # ---------------------------------------------------------------------
         # Проверка наличия в источнике данных указанных столбцов.
 
-        data_source = registry.get(
-            self._report_template.data_source_name
-        ).get_data_source_descriptor()
+        data_source = registry.get(self._report_template.data_source_name).get_data_source_descriptor()
 
         for column_params in columns_data:
             if 'accessor_name' not in column_params:
-                self.errors.append(u'Колонки отчета заданы неверно.')
+                self.errors.append('Колонки отчета заданы неверно.')
                 break
 
             full_accessor_name = column_params['accessor_name']
             if full_accessor_name in self._column_descriptors:
-                self.errors.append(
-                    u'Колонка {} указана более одного раза.'
-                    .format(full_accessor_name)
-                )
+                self.errors.append('Колонка {} указана более одного раза.'.format(full_accessor_name))
             else:
                 try:
-                    column_descriptor = data_source.get_column_descriptor(
-                        full_accessor_name
-                    )
+                    column_descriptor = data_source.get_column_descriptor(full_accessor_name)
                 except FieldDoesNotExist:
                     self.errors.append(
-                        u'Колонки "{}" нет в источнике данных "{}".'
-                        .format(full_accessor_name, data_source.title)
+                        'Колонки "{}" нет в источнике данных "{}".'.format(full_accessor_name, data_source.title)
                     )
                 else:
-                    self._column_descriptors[full_accessor_name] = (
-                        column_descriptor
-                    )
+                    self._column_descriptors[full_accessor_name] = column_descriptor
 
-        if not any(
-            column_params.get('visible', False)
-            for column_params in columns_data
-        ):
-            self.errors.append(u'В отчете нет ни одного видимого столбца.')
+        if not any(column_params.get('visible', False) for column_params in columns_data):
+            self.errors.append('В отчете нет ни одного видимого столбца.')
         # ---------------------------------------------------------------------
 
         return not self.errors
 
     def _is_filters_data_valid(self, filters_data):
-        u"""Возвращает True, если параметры фильтров корректны.
+        """Возвращает True, если параметры фильтров корректны.
 
         :rtype: bool
         """
         if not isinstance(filters_data, dict):
             return False
 
-        for operator, filters in six.iteritems(filters_data):
+        for operator, filters in filters_data.items():
             if operator not in ('AND', 'OR'):
                 return False
 
@@ -665,12 +620,8 @@ class ReportTemplateWriter(object):
                     return False
 
                 # Проверка вложенной группы фильтров.
-                if (
-                    'AND' in filter_params and
-                    not self._is_filters_data_valid(filter_params['AND'])
-                ) or (
-                    'OR' in filter_params and
-                    not self._is_filters_data_valid(filter_params['OR'])
+                if ('AND' in filter_params and not self._is_filters_data_valid(filter_params['AND'])) or (
+                    'OR' in filter_params and not self._is_filters_data_valid(filter_params['OR'])
                 ):
                     return False
 
@@ -681,19 +632,16 @@ class ReportTemplateWriter(object):
                     'values',
                 )
                 if (
-                    'AND' not in filter_params and
-                    'OR' not in filter_params and
-                    any(
-                        param_name not in filter_params
-                        for param_name in param_names
-                    )
+                    'AND' not in filter_params
+                    and 'OR' not in filter_params
+                    and any(param_name not in filter_params for param_name in param_names)
                 ):
                     return False
 
         return True
 
     def _is_sorting_data_valid(self, sorting_data):
-        u"""Возвращает True, если параметры сортировки корректны.
+        """Возвращает True, если параметры сортировки корректны.
 
         :rtype: bool
         """
@@ -706,58 +654,40 @@ class ReportTemplateWriter(object):
                 'column',
                 'direction',
             )
-            if any(
-                param_name not in sorting_params
-                for param_name in param_names
-            ):
+            if any(param_name not in sorting_params for param_name in param_names):
                 return False
 
         return True
 
     def validate(self):
-        u"""Выполняет проверку параметров отчета перед его сохранением.
+        """Выполняет проверку параметров отчета перед его сохранением.
 
         :raises objectpack.exceptions.ValidationError: если во время проверки
             найдены ошибки.
         """
         if not self._is_report_template_valid(self._report_template):
-            raise ValidationError(
-                u'Параметры шаблона указаны некорректно.'
-            )
+            raise ValidationError('Параметры шаблона указаны некорректно.')
         if not self._is_columns_data_valid(self._columns_data):
-            raise ValidationError(
-                u'Параметры столбцов указаны некорректно.'
-            )
+            raise ValidationError('Параметры столбцов указаны некорректно.')
         if not self._is_filters_data_valid(self._filters_data):
-            raise ValidationError(
-                u'Параметры фильтров указаны некорректно.'
-            )
+            raise ValidationError('Параметры фильтров указаны некорректно.')
         if not self._is_sorting_data_valid(self._sorting_data):
-            raise ValidationError(
-                u'Параметры сортировки указаны некорректно.'
-            )
+            raise ValidationError('Параметры сортировки указаны некорректно.')
 
     def _write_template(self):
-        u"""Сохранение в БД шаблона отчета."""
+        """Сохранение в БД шаблона отчета."""
         self._report_template.clean_and_save()
 
     def _write_columns(self):
-        u"""Сохранение в БД столбцов."""
+        """Сохранение в БД столбцов."""
         column_descriptor_names = set(
-            column_descriptor.full_accessor_name
-            for column_descriptor in six.itervalues(self._column_descriptors)
+            column_descriptor.full_accessor_name for column_descriptor in self._column_descriptors.values()
         )
 
         columns_query = self._report_template.columns.order_by('index')
-        report_columns = OrderedDict(
-            (report_column.name, report_column)
-            for report_column in columns_query
-        )
+        report_columns = OrderedDict((report_column.name, report_column) for report_column in columns_query)
 
-        columns_data = {
-            column_data['accessor_name']: column_data
-            for column_data in self._columns_data
-        }
+        columns_data = {column_data['accessor_name']: column_data for column_data in self._columns_data}
         # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
         # Сначала нужно удалить столбцы, которых нет в запросе.
 
@@ -767,12 +697,8 @@ class ReportTemplateWriter(object):
         # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 
         created_report_columns = []
-        for index, column_descriptor in enumerate(
-            six.itervalues(self._column_descriptors), 1
-        ):
-            report_column = report_columns.get(
-                column_descriptor.full_accessor_name
-            )
+        for index, column_descriptor in enumerate(self._column_descriptors.values(), 1):
+            report_column = report_columns.get(column_descriptor.full_accessor_name)
 
             column_data = columns_data[column_descriptor.full_accessor_name]
             visible = column_data.get('visible', False)
@@ -788,17 +714,17 @@ class ReportTemplateWriter(object):
                         title=column_descriptor.title,
                         visible=visible,
                         by_value=by_value,
-                        total=total
+                        total=total,
                     )
                 )
 
             elif (
-                report_column.name != column_descriptor.full_accessor_name or
-                report_column.index != index or
-                report_column.title != column_descriptor.title or
-                report_column.visible != visible or
-                report_column.by_value != by_value or
-                report_column.total != total
+                report_column.name != column_descriptor.full_accessor_name
+                or report_column.index != index
+                or report_column.title != column_descriptor.title
+                or report_column.visible != visible
+                or report_column.by_value != by_value
+                or report_column.total != total
             ):
                 report_column.name = column_descriptor.full_accessor_name
                 report_column.index = index
@@ -811,13 +737,12 @@ class ReportTemplateWriter(object):
         # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
         # Сохранение столбцов для дальнейшего использования.
 
-        for report_column in chain(six.itervalues(report_columns),
-                                   created_report_columns):
+        for report_column in chain(report_columns.values(), created_report_columns):
             self._report_columns[report_column.name] = report_column
         # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 
     def _write_filter_group(self, parent_group, operator, filters):
-        u"""Сохранение в БД групп фильтров."""
+        """Сохранение в БД групп фильтров."""
         report_filter_group = ReportFilterGroup(
             report_template=self._report_template,
             parent=parent_group,
@@ -856,14 +781,14 @@ class ReportTemplateWriter(object):
                 )
 
     def _write_filters(self):
-        u"""Сохранение в БД фильтров."""
+        """Сохранение в БД фильтров."""
         # Чтобы не разбираться с имеющимся деревом фильтров, удалим его и
         # создадим заново.
 
         self._report_template.filter_groups.all().delete()
         # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 
-        for operator, filters in six.iteritems(self._filters_data):
+        for operator, filters in self._filters_data.items():
             if operator == 'OR':
                 operator = ReportFilterGroup.OPERATOR_OR
             else:
@@ -873,7 +798,7 @@ class ReportTemplateWriter(object):
         # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 
     def _write_sorting(self):
-        u"""Сохранение в БД параметров сортировки."""
+        """Сохранение в БД параметров сортировки."""
         sorting_params = chain(self._sorting_data, repeat(None))
         sorting_objs = chain(
             ReportSorting.objects.filter(
@@ -903,7 +828,7 @@ class ReportTemplateWriter(object):
     @convert_validation_error_to(ValidationError)
     @atomic
     def write(self):
-        u"""Сохранение в БД данных шаблона отчета."""
+        """Сохранение в БД данных шаблона отчета."""
         self._write_template()
         self._write_columns()
         self._write_filters()
@@ -911,8 +836,7 @@ class ReportTemplateWriter(object):
 
 
 class Pack(PackValidationMixin, ObjectPack):
-
-    u"""Пак реестра шаблонов отчетов."""
+    """Пак реестра шаблонов отчетов."""
 
     model = ReportTemplate
     _is_primary_for_model = False
@@ -934,30 +858,30 @@ class Pack(PackValidationMixin, ObjectPack):
     add_window = edit_window = EditWindow
 
     def __init__(self):
-        super(Pack, self).__init__()
-        # ---------------------------------------------------------------------
+        super().__init__()
+
         self.columns_action = ColumnsAction()
         self.build_action = BuildAction()
 
-        self.actions.extend((
-            self.columns_action,
-            self.build_action,
-        ))
-        # ---------------------------------------------------------------------
+        self.actions.extend(
+            (
+                self.columns_action,
+                self.build_action,
+            )
+        )
 
     def prepare_row(self, obj, request, context):
-        obj = super(Pack, self).prepare_row(
-            obj, request, context
-        )
+        obj = super().prepare_row(obj, request, context)
+
         obj.valid = not (ReportInfo(obj).ignored_columns_ids)
         return obj
 
     def declare_context(self, action):
-        result = super(Pack, self).declare_context(action)
+        result = super().declare_context(action)
 
         if action is self.save_action:
             result.update(
-                title=dict(type='unicode'),
+                title=dict(type='str'),
                 data_source_name=dict(type='str'),
                 columns=dict(type='json'),
                 filters=dict(type='json', default={}),
@@ -967,24 +891,18 @@ class Pack(PackValidationMixin, ObjectPack):
         return result
 
     def get_list_window_params(self, params, request, context):
-        result = super(Pack, self).get_list_window_params(
-            params, request, context
-        )
+        result = super().get_list_window_params(params, request, context)
 
         result['build_action_url'] = self.build_action.get_absolute_url()
 
         return result
 
     def get_edit_window_params(self, params, request, context):
-        result = super(Pack, self).get_edit_window_params(
-            params, request, context
-        )
+        result = super().get_edit_window_params(params, request, context)
 
         result['maximized'] = True
 
-        result['available_columns_action_url'] = (
-            self.columns_action.get_absolute_url()
-        )
+        result['available_columns_action_url'] = self.columns_action.get_absolute_url()
 
         # pylint: disable=dict-iter-method
         result['data_sources_params'] = registry.iteritems()
@@ -1015,10 +933,7 @@ class Pack(PackValidationMixin, ObjectPack):
         try:
             writer.validate()
         except ValidationError as error:
-            raise ValidationError(u'\n'.join((
-                six.text_type(error),
-                u'\n'.join(writer.errors)
-            )))
+            raise ValidationError('\n'.join((str(error), '\n'.join(writer.errors))))
 
         writer.write()
 
@@ -1044,13 +959,13 @@ class Pack(PackValidationMixin, ObjectPack):
         ).iterator():
             report_column.safe_delete()
 
-        super(Pack, self).delete_row(obj_id, request, context)
+        super().delete_row(obj_id, request, context)
 
     def extend_menu(self, menu):
         return menu.SubMenu(
-            u'Отчеты',
+            'Отчеты',
             menu.SubMenu(
-                u'Конструктор отчетов',
-                menu.Item(u'Редактор шаблонов', self.list_window_action),
-            )
+                'Конструктор отчетов',
+                menu.Item('Редактор шаблонов', self.list_window_action),
+            ),
         )
