@@ -1,40 +1,36 @@
-# coding: utf-8
-from __future__ import absolute_import
-from __future__ import unicode_literals
-
-from django.db import migrations
-from django.db import models
 import django.contrib.postgres.fields
 import django.db.models.deletion
+from django.db import (
+    migrations,
+    models,
+)
 
 
 class Migration(migrations.Migration):
-
-    dependencies = [('report_constructor', '0006_reportsorting'), ]
+    dependencies = [
+        ('report_constructor', '0006_reportsorting'),
+    ]
 
     operations = [
         migrations.AlterModelOptions(
             name='reportsorting',
-            options={
-                'ordering': ('index', ),
-                'verbose_name': 'Сортировка',
-                'verbose_name_plural': 'Сортировка'
-            }, ),
+            options={'ordering': ('index',), 'verbose_name': 'Сортировка', 'verbose_name_plural': 'Сортировка'},
+        ),
         migrations.AddField(
             model_name='reporttemplate',
             name='include_available_units',
-            field=models.BooleanField(
-                default=False,
-                verbose_name='Отображать данные по дочерним учреждениям'), ),
+            field=models.BooleanField(default=False, verbose_name='Отображать данные по дочерним учреждениям'),
+        ),
         migrations.AlterField(
             model_name='reportfilter',
             name='values',
             field=django.contrib.postgres.fields.ArrayField(
-                base_field=models.TextField(
-                    blank=True, null=True, verbose_name='Значение'),
+                base_field=models.TextField(blank=True, null=True, verbose_name='Значение'),
                 blank=True,
                 null=True,
-                size=None), ),
+                size=None,
+            ),
+        ),
         migrations.AlterField(
             model_name='reportsorting',
             name='column',
@@ -42,5 +38,7 @@ class Migration(migrations.Migration):
                 on_delete=django.db.models.deletion.CASCADE,
                 related_name='sorting',
                 to='report_constructor.ReportColumn',
-                verbose_name='Колонка'), ),
+                verbose_name='Колонка',
+            ),
+        ),
     ]
