@@ -1,12 +1,14 @@
-# coding: utf-8
-from objectpack.actions import BasePack
+from objectpack.actions import (
+    BasePack,
+)
 
-from . import mixins
+from educommon.rest import (
+    mixins,
+)
 
 
 class BaseRestPack(BasePack):
-
-    """Базовый пак для всех REST пакокв."""
+    """Базовый пак для всех REST паков."""
 
 
 class RestPack(
@@ -15,10 +17,10 @@ class RestPack(
     mixins.CreateModelMixin,
     mixins.UpdateModelMixin,
     mixins.DestroyModelMixin,
-    BaseRestPack
+    BaseRestPack,
 ):
-    """
-    Пак для обработки запросов методами: GET, POST, PUT, PATCH, DELETE.
+    """Пак для обработки запросов методами: GET, POST, PUT, PATCH, DELETE.
+
     Для обработки запросов методом GET исользуются методы пака list и retrieve.
     Для обработки запросов методом POST используется метод пака create.
     Для обработки запросов методом PUT и PATCH используется метод пака update.
@@ -26,12 +28,8 @@ class RestPack(
     """
 
 
-class RestReadOnlyPack(
-    mixins.ListModelMixin,
-    mixins.RetrieveModelMixin,
-    BaseRestPack
-):
-    """
-    Пак который обрабатывает запросы только методом GET.
+class RestReadOnlyPack(mixins.ListModelMixin, mixins.RetrieveModelMixin, BaseRestPack):
+    """Пак который обрабатывает запросы только методом GET.
+
     Доступные методы пака: list и retrieve.
     """
