@@ -1,15 +1,17 @@
-# coding: utf-8
-from __future__ import absolute_import
+from contextlib import (
+    closing,
+)
 
-from contextlib import closing
-
-from django.db import connections
-from django.db.utils import ProgrammingError
-import six
+from django.db import (
+    connections,
+)
+from django.db.utils import (
+    ProgrammingError,
+)
 
 
 def is_extension_exists(alias, name):
-    u"""Возвращает True, если в БД доступно расширение с указанным именем.
+    """Возвращает True, если в БД доступно расширение с указанным именем.
 
     :param str alias: Алиас базы данных (напр. ``'default'``).
     :param str name: Имя расширения.
@@ -17,15 +19,12 @@ def is_extension_exists(alias, name):
     :rtype: bool
     """
     with closing(connections[alias].cursor()) as cursor:
-        cursor.execute(
-            "SELECT 1 FROM pg_extension WHERE extname = %s",
-            (name,)
-        )
+        cursor.execute('SELECT 1 FROM pg_extension WHERE extname = %s', (name,))
         return cursor.fetchone() is not None
 
 
 def create_extension(alias, name, quite=False):
-    u"""Создает в БД расширение PostgreSQL.
+    """Создает в БД расширение PostgreSQL.
 
     :param str alias: Алиас базы данных (напр. ``'default'``).
     :param str name: Имя расширения.
@@ -48,9 +47,8 @@ def create_extension(alias, name, quite=False):
             return True
 
 
-class Lock(object):
-
-    u"""Блокировка с помощью функции PostgreSQL ``pg_advisory_lock``.
+class Lock:
+    """Блокировка с помощью функции PostgreSQL ``pg_advisory_lock``.
 
     .. seealso::
 
@@ -59,7 +57,7 @@ class Lock(object):
     """
 
     def __init__(self, alias, key):
-        u"""Инициализация экземпляра.
+        """Инициализация экземпляра.
 
         :param str alias: Алиас базы данных.
 
@@ -70,7 +68,7 @@ class Lock(object):
 
         self.alias = alias
 
-        if isinstance(key, six.string_types):
+        if isinstance(key, str):
             self.key = hash(key)
         else:
             self.key = int(key)
