@@ -1,17 +1,14 @@
-# coding: utf-8
-from __future__ import absolute_import
-from __future__ import unicode_literals
-
-import abc
-
-import six
+from abc import (
+    ABCMeta,
+    abstractmethod,
+)
 
 
-class IConfig(six.with_metaclass(abc.ABCMeta, object)):
-
+class IConfig(metaclass=ABCMeta):
     """Класс интерфейс для конфигурации менеджера логгеров веб-сервисов."""
 
-    @abc.abstractproperty
+    @property
+    @abstractmethod
     def loggers(self):
         """Список логгеров Системы.
 
