@@ -1,13 +1,10 @@
-# coding: utf-8
-from __future__ import absolute_import
-from __future__ import unicode_literals
-
-from django.db import migrations
-from django.db import models
+from django.db import (
+    migrations,
+    models,
+)
 
 
 class Migration(migrations.Migration):
-
     dependencies = [
         ('ws_log', '0001_initial'),
     ]
